// This file is generated with "update_icon_font.py" from FontAwesome's metadata.

struct Icon {
    unsigned short unicode;
    bool isBrand;
    const char *searchTerms;
};

constexpr Icon iconList[] = {
{0x30, false, "0|Digit Zero|nada|none|zero|zilch"},
{0x31, false, "1|Digit One|one"},
{0x32, false, "2|Digit Two|two"},
{0x33, false, "3|Digit Three|three"},
{0x34, false, "4|Digit Four|four"},
{0x35, false, "5|Digit Five|five"},
{0x36, false, "6|Digit Six|six"},
{0x37, false, "7|Digit Seven|seven"},
{0x38, false, "8|Digit Eight|eight"},
{0x39, false, "9|Digit Nine|nine"},
{0x41, false, "a|Latin Capital Letter A|Latin Small Letter A|letter"},
{0xf2b9, false, "address book|contact|directory|employee|index|little black book|portfolio|rolodex|uer|username"},
{0xf2bb, false, "address card|about|contact|employee|id|identification|portfolio|postcard|profile|registration|uer|username"},
{0xf037, false, "align center|format|middle|paragraph|text"},
{0xf039, false, "align justify|format|paragraph|text"},
{0xf036, false, "align left|format|paragraph|text"},
{0xf038, false, "align right|format|paragraph|text"},
{0xf13d, false, "anchor|anchor|berth|boat|dock|embed|link|maritime|moor|port|secure|ship|tool"},
{0xe4aa, false, "anchor circle check|enable|marina|not affected|ok|okay|port|validate|working"},
{0xe4ab, false, "anchor circle exclamation|affected|failed|marina|port"},
{0xe4ac, false, "anchor circle xmark|destroy|marina|port|uncheck"},
{0xe4ad, false, "anchor lock|closed|lockdown|marina|padlock|port|privacy|quarantine"},
{0xf107, false, "angle down|Down Arrowhead|arrow|caret|download|expand|insert"},
{0xf104, false, "angle left|Single Left-Pointing Angle Quotation Mark|arrow|back|caret|less|previous"},
{0xf105, false, "angle right|Single Right-Pointing Angle Quotation Mark|arrow|care|forward|more|next"},
{0xf106, false, "angle up|Up Arrowhead|arrow|caret|collapse|upgrade|upload"},
{0xf103, false, "angles down|arrows|caret|download|expand"},
{0xf100, false, "angles left|Left-Pointing Double Angle Quotation Mark|arrows|back|caret|laquo|previous|quote"},
{0xf101, false, "angles right|Right-Pointing Double Angle Quotation Mark|arrows|caret|forward|more|next|quote|raquo"},
{0xf102, false, "angles up|arrows|caret|collapse|upload"},
{0xf644, false, "ankh|Ankh|amulet|copper|coptic christianity|copts|crux ansata|egypt|venus"},
{0xf5d1, false, "apple whole|apple|fall|fruit|fuji|green|green apple|macintosh|orchard|red|red apple|seasonal|vegan"},
{0xf557, false, "archway|arc|monument|road|street|tunnel"},
{0xf063, false, "arrow down|Downwards Arrow|download"},
{0xf162, false, "arrow down 1 9|arrange|filter|numbers|order|sort-numeric-asc"},
{0xf886, false, "arrow down 9 1|arrange|filter|numbers|order|sort-numeric-asc"},
{0xf15d, false, "arrow down a z|alphabetical|arrange|filter|order|sort-alpha-asc"},
{0xf175, false, "arrow down long|download|long-arrow-down"},
{0xf884, false, "arrow down short wide|arrange|filter|order|sort-amount-asc"},
{0xe4af, false, "arrow down up across line|border|crossing|transfer"},
{0xe4b0, false, "arrow down up lock|border|closed|crossing|lockdown|padlock|privacy|quarantine|transfer"},
{0xf160, false, "arrow down wide short|arrange|filter|number|order|sort-amount-asc"},
{0xf881, false, "arrow down z a|alphabetical|arrange|filter|order|sort-alpha-asc"},
{0xf060, false, "arrow left|Leftwards Arrow|back|previous"},
{0xf177, false, "arrow left long|back|long-arrow-left|previous"},
{0xf245, false, "arrow pointer|arrow|cursor|select"},
{0xf061, false, "arrow right|Rightwards Arrow|forward|next"},
{0xf0ec, false, "arrow right arrow left|Rightwards Arrow Over Leftwards Arrow|arrow|arrows|reciprocate|return|swap|transfer"},
{0xf08b, false, "arrow right from bracket|arrow|exit|leave|log out|logout"},
{0xf178, false, "arrow right long|forward|long-arrow-right|next"},
{0xf090, false, "arrow right to bracket|arrow|enter|insert|join|log in|login|sign in|sign up|sign-in|signin|signup"},
{0xe4b3, false, "arrow right to city|building|city|exodus|insert|rural|urban"},
{0xf0e2, false, "arrow rotate left|Anticlockwise Open Circle Arrow|back|control z|exchange|oops|return|rotate|swap"},
{0xf01e, false, "arrow rotate right|Clockwise Open Circle Arrow|forward|refresh|reload|renew|repeat|retry"},
{0xe097, false, "arrow trend down|line|stocks|trend"},
{0xe098, false, "arrow trend up|line|stocks|trend"},
{0xf149, false, "arrow turn down|arrow"},
{0xf148, false, "arrow turn up|arrow"},
{0xf062, false, "arrow up|Upwards Arrow|forward|upgrade|upload"},
{0xf163, false, "arrow up 1 9|arrange|filter|numbers|order|sort-numeric-desc"},
{0xf887, false, "arrow up 9 1|arrange|filter|numbers|order|sort-numeric-desc"},
{0xf15e, false, "arrow up a z|alphabetical|arrange|filter|order|sort-alpha-desc"},
{0xe09a, false, "arrow up from bracket|share|transfer|upgrade|upload"},
{0xe4b5, false, "arrow up from ground water|groundwater|spring|upgrade|water supply|water table"},
{0xe4b6, false, "arrow up from water pump|flood|groundwater|pump|submersible|sump pump|upgrade"},
{0xf176, false, "arrow up long|long-arrow-up|upload"},
{0xe4b7, false, "arrow up right dots|growth|increase|population|upgrade"},
{0xf08e, false, "arrow up right from square|new|open|send|share|upgrade"},
{0xf885, false, "arrow up short wide|arrange|filter|order|sort-amount-desc"},
{0xf161, false, "arrow up wide short|arrange|filter|order|sort-amount-desc|upgrade"},
{0xf882, false, "arrow up z a|alphabetical|arrange|filter|order|sort-alpha-desc"},
{0xe4b8, false, "arrows down to line|insert|scale down|sink"},
{0xe4b9, false, "arrows down to people|affected|focus|insert|targeted|together|uer"},
{0xf07e, false, "arrows left right|expand|horizontal|landscape|resize|wide"},
{0xe4ba, false, "arrows left right to line|analysis|expand|gap"},
{0xf021, false, "arrows rotate|Clockwise Right and Left Semicircle Arrows|clockwise|exchange|modify|refresh|reload|renew|retry|rotate|swap"},
{0xe4bb, false, "arrows spin|cycle|rotate|spin|whirl"},
{0xe4bc, false, "arrows split up and left|agile|split"},
{0xe4bd, false, "arrows to circle|center|concentrate|coordinate|coordination|focal point|focus|insert"},
{0xe4be, false, "arrows to dot|assembly point|center|condense|focus|insert|minimize"},
{0xe4bf, false, "arrows to eye|center|coordinated assessment|focus"},
{0xe4c0, false, "arrows turn right|arrows"},
{0xe4c1, false, "arrows turn to dots|destination|insert|nexus"},
{0xf07d, false, "arrows up down|expand|portrait|resize|tall|vertical"},
{0xf047, false, "arrows up down left right|arrow|arrows|bigger|enlarge|expand|fullscreen|move|position|reorder|resize"},
{0xe4c2, false, "arrows up to line|rise|scale up|upgrade"},
{0x2a, false, "asterisk|Asterisk|Heavy Asterisk|annotation|details|reference|required|star"},
{0x40, false, "at|Commercial At|address|author|e-mail|email|fluctuate|handle"},
{0xf5d2, false, "atom|atheism|atheist|atom|atom symbol|chemistry|electron|ion|isotope|knowledge|neutron|nuclear|proton|science"},
{0xf29e, false, "audio description|blind|narration|video|visual"},
{0xe0a9, false, "austral sign|Austral Sign|currency"},
{0xf559, false, "award|guarantee|honor|praise|prize|recognition|ribbon|trophy|warranty"},
{0x42, false, "b|Latin Capital Letter B|Latin Small Letter B|letter"},
{0xf77c, false, "baby|uer|users-people"},
{0xf77d, false, "baby carriage|buggy|carrier|infant|push|stroller|transportation|walk|wheels"},
{0xf04a, false, "backward|arrow|double|fast reverse button|previous|rewind"},
{0xf049, false, "backward fast|arrow|beginning|first|last track button|previous|previous scene|previous track|quick|rewind|start|triangle"},
{0xf048, false, "backward step|beginning|first|previous|rewind|start"},
{0xf7e5, false, "bacon|bacon|blt|breakfast|food|ham|lard|meat|pancetta|pork|rasher"},
{0xe059, false, "bacteria|antibiotic|antibody|covid-19|health|organism|sick"},
{0xe05a, false, "bacterium|antibiotic|antibody|covid-19|health|organism|sick"},
{0xf290, false, "bag shopping|buy|checkout|grocery|payment|purchase"},
{0xf666, false, "bahai|bahai|bahá'í|star"},
{0xe0ac, false, "baht sign|currency"},
{0xf05e, false, "ban|404|abort|ban|block|cancel|delete|deny|disabled|entry|failed|forbidden|hide|no|not|not found|prohibit|prohibited|remove|stop|trash"},
{0xf54d, false, "ban smoking|ban|cancel|deny|disabled|forbidden|no|no smoking|non-smoking|not|prohibited|smoking"},
{0xf462, false, "bandage|adhesive bandage|bandage|boo boo|first aid|modify|ouch"},
{0xe2e6, false, "bangladeshi taka sign|bdt|currency|tk"},
{0xf02a, false, "barcode|info|laser|price|scan|upc"},
{0xf0c9, false, "bars|checklist|drag|hamburger|list|menu|nav|navigation|ol|reorder|settings|todo|ul"},
{0xf828, false, "bars progress|checklist|downloading|downloads|loading|poll|progress|project management|settings|to do"},
{0xf550, false, "bars staggered|flow|list|timeline"},
{0xf433, false, "baseball|ball|baseball|foul|glove|hardball|league|leather|mlb|softball|sport|underarm"},
{0xf432, false, "baseball bat ball|bat|league|mlb|slugger|softball|sport"},
{0xf291, false, "basket shopping|buy|checkout|grocery|payment|purchase"},
{0xf434, false, "basketball|ball|basketball|dribble|dunk|hoop|nba"},
{0xf2cd, false, "bath|bath|bathtub|clean|shower|tub|wash"},
{0xf244, false, "battery empty|charge|dead|power|status"},
{0xf240, false, "battery full|batter|battery|charge|power|status"},
{0xf242, false, "battery half|charge|power|status"},
{0xf243, false, "battery quarter|charge|low|power|status"},
{0xf241, false, "battery three quarters|charge|power|status"},
{0xf236, false, "bed|hospital|hotel|lodging|mattress|patient|person in bed|rest|sleep|travel|uer"},
{0xf487, false, "bed pulse|EKG|bed|electrocardiogram|health|hospital|life|patient|vital"},
{0xf0fc, false, "beer mug empty|alcohol|ale|bar|beverage|brew|brewery|drink|foam|lager|liquor|mug|stein"},
{0xf0f3, false, "bell|alarm|alert|bel|bell|chime|notification|reminder|request"},
{0xf562, false, "bell concierge|attention|bell|bellhop|bellhop bell|hotel|receptionist|request|service|support"},
{0xf1f6, false, "bell slash|alert|bell|bell with slash|cancel|disabled|forbidden|mute|notification|off|quiet|reminder|silent"},
{0xf55b, false, "bezier curve|curves|illustrator|lines|path|vector"},
{0xf206, false, "bicycle|bicycle|bike|gears|pedal|transportation|vehicle"},
{0xf1e5, false, "binoculars|glasses|inspection|magnifier|magnify|scenic|spyglass|view"},
{0xf780, false, "biohazard|biohazard|covid-19|danger|dangerous|epidemic|hazmat|medical|pandemic|radioactive|sign|toxic|waste|zombie"},
{0xe0b4, false, "bitcoin sign|Bitcoin Sign|currency"},
{0xf517, false, "blender|cocktail|milkshake|mixer|puree|smoothie"},
{0xf6b6, false, "blender phone|appliance|cocktail|fantasy|milkshake|mixer|puree|silly|smoothie"},
{0xf781, false, "blog|journal|log|online|personal|post|web 2.0|wordpress|writing"},
{0xf032, false, "bold|emphasis|format|text"},
{0xf0e7, false, "bolt|charge|danger|electric|electricity|flash|high voltage|lightning|voltage|weather|zap"},
{0xe0b7, false, "bolt lightning|electricity|flash|lightning|weather|zap"},
{0xf1e2, false, "bomb|bomb|comic|error|explode|fuse|grenade|warning"},
{0xf5d7, false, "bone|bone|calcium|dog|skeletal|skeleton|tibia"},
{0xf55c, false, "bong|aparatus|cannabis|marijuana|pipe|smoke|smoking"},
{0xf02d, false, "book|book|cover|decorated|diary|documentation|journal|knowledge|library|notebook|notebook with decorative cover|read|research|scholar"},
{0xf558, false, "book atlas|book|directions|geography|globe|knowledge|library|map|research|travel|wayfinding"},
{0xf647, false, "book bible|book|catholicism|christianity|god|holy"},
{0xe0bb, false, "book bookmark|knowledge|library|research"},
{0xf66a, false, "book journal whills|book|force|jedi|sith|star wars|yoda"},
{0xf7e6, false, "book medical|diary|documentation|health|history|journal|library|read|record|research"},
{0xf518, false, "book open|Book|book|flyer|knowledge|library|notebook|open|open book|pamphlet|reading|research"},
{0xf5da, false, "book open reader|flyer|library|notebook|open book|pamphlet|reading|research"},
{0xf687, false, "book quran|book|islam|muslim|religion"},
{0xf6b7, false, "book skull|Dungeons & Dragons|crossbones|d&d|dark arts|death|dnd|documentation|evil|fantasy|halloween|holiday|library|necronomicon|read|research|skull|spell"},
{0xf827, false, "book tanakh|book|jewish|judaism|religion"},
{0xf02e, false, "bookmark|bookmark|favorite|library|mark|marker|read|remember|research|save"},
{0xf84c, false, "border all|cell|grid|outline|stroke|table"},
{0xf850, false, "border none|cell|grid|outline|stroke|table"},
{0xf853, false, "border top left|cell|outline|stroke|table"},
{0xe4c3, false, "bore hole|bore|bury|drill|hole"},
{0xe4c4, false, "bottle droplet|alcohol|drink|oil|olive oil|wine"},
{0xe4c5, false, "bottle water|h2o|plastic|water"},
{0xe4c6, false, "bowl food|catfood|dogfood|food|rice"},
{0xe2eb, false, "bowl rice|boiled|cooked|cooked rice|rice|steamed"},
{0xf436, false, "bowling ball|alley|candlepin|gutter|lane|strike|tenpin"},
{0xf466, false, "box|archive|box|container|package|parcel|storage"},
{0xf187, false, "box archive|box|package|save|storage"},
{0xf49e, false, "box open|archive|container|package|storage|unpack"},
{0xe05b, false, "box tissue|cough|covid-19|kleenex|mucus|nose|sneeze|snot"},
{0xe4c7, false, "boxes packing|archive|box|package|storage|supplies"},
{0xf468, false, "boxes stacked|archives|inventory|storage|warehouse"},
{0xf2a1, false, "braille|alphabet|blind|dots|raised|vision"},
{0xf5dc, false, "brain|brain|cerebellum|gray matter|intellect|intelligent|knowledge|medulla oblongata|mind|noodle|scholar|wit"},
{0xe46c, false, "brazilian real sign|brazilian real sign|currency"},
{0xf7ec, false, "bread slice|bake|bakery|baking|dough|flour|gluten|grain|sandwich|sourdough|toast|wheat|yeast"},
{0xe4c8, false, "bridge|bridge|road"},
{0xe4c9, false, "bridge circle check|bridge|enable|not affected|ok|okay|road|validate|working"},
{0xe4ca, false, "bridge circle exclamation|affected|bridge|failed|road"},
{0xe4cb, false, "bridge circle xmark|bridge|destroy|road|uncheck"},
{0xe4cc, false, "bridge lock|bridge|closed|lockdown|padlock|privacy|quarantine|road"},
{0xe4ce, false, "bridge water|bridge|road"},
{0xf0b1, false, "briefcase|bag|briefcas|briefcase|business|luggage|offer|office|portfolio|work"},
{0xf469, false, "briefcase medical|doctor|emt|first aid|health"},
{0xf51a, false, "broom|broom|clean|cleaning|firebolt|fly|halloween|nimbus 2000|quidditch|sweep|sweeping|witch"},
{0xf458, false, "broom ball|ball|bludger|broom|golden snitch|harry potter|hogwarts|quaffle|sport|wizard"},
{0xf55d, false, "brush|art|bristles|color|handle|maintenance|modify|paint"},
{0xe4cf, false, "bucket|bucket|pail|sandcastle"},
{0xf188, false, "bug|beetle|error|glitch|insect|repair|report"},
{0xe490, false, "bug slash|beetle|disabled|fix|glitch|insect|optimize|repair|report|warning"},
{0xe4d0, false, "bugs|bedbug|infestation|lice|plague|ticks"},
{0xf1ad, false, "building|apartment|building|business|city|company|office|office building|urban|work"},
{0xe4d1, false, "building circle arrow right|building|city|distribution center|office"},
{0xe4d2, false, "building circle check|building|city|enable|not affected|office|ok|okay|validate|working"},
{0xe4d3, false, "building circle exclamation|affected|building|city|failed|office"},
{0xe4d4, false, "building circle xmark|building|city|destroy|office|uncheck"},
{0xf19c, false, "building columns|bank|building|college|education|institution|museum|students"},
{0xe4d5, false, "building flag| city|building|diplomat|embassy|flag|headquarters|united nations"},
{0xe4d6, false, "building lock|building|city|closed|lock|lockdown|padlock|privacy|quarantine|secure"},
{0xe4d7, false, "building ngo| city|building|non governmental organization|office"},
{0xe4d8, false, "building shield|building|city|police|protect|safety"},
{0xe4d9, false, "building un|building|city|office|united nations"},
{0xe4da, false, "building user|apartment|building|city|employee|uer"},
{0xe4db, false, "building wheat|agriculture|building|city|usda"},
{0xf0a1, false, "bullhorn|Bullhorn|announcement|broadcast|loud|louder|loudspeaker|megaphone|public address|request|share"},
{0xf140, false, "bullseye|archery|goal|objective|strategy|target"},
{0xf805, false, "burger|bacon|beef|burger|burger king|cheeseburger|fast food|grill|ground beef|mcdonalds|sandwich"},
{0xe4dc, false, "burst|boom|crash|explosion"},
{0xf207, false, "bus|bus|oncoming|oncoming bus|public transportation|transportation|travel|vehicle"},
{0xf55e, false, "bus simple|mta|public transportation|transportation|travel|vehicle"},
{0xf64a, false, "business time|alarm|briefcase|business socks|clock|flight of the conchords|portfolio|reminder|wednesday"},
{0x43, false, "c|Latin Capital Letter C|Latin Small Letter C|letter"},
{0xf7da, false, "cable car|aerial tramway|cable|gondola|lift|mountain|mountain cableway|tram|tramway|trolley"},
{0xf1fd, false, "cake candles|anniversary|bakery|birthday|birthday cake|cake|candles|celebration|dessert|frosting|holiday|party|pastry|sweet"},
{0xf1ec, false, "calculator|Pocket Calculator|abacus|addition|arithmetic|counting|math|multiplication|subtraction"},
{0xf133, false, "calendar|calendar|calendar-o|date|day|event|month|schedule|tear-off calendar|time|when|year"},
{0xf274, false, "calendar check|accept|agree|appointment|confirm|correct|date|day|done|enable|event|month|ok|schedule|select|success|tick|time|todo|validate|warranty|when|working|year"},
{0xf783, false, "calendar day|date|day|detail|event|focus|month|schedule|single day|time|today|when|year"},
{0xf073, false, "calendar days|calendar|date|day|event|month|schedule|time|when|year"},
{0xf272, false, "calendar minus|calendar|date|day|delete|event|month|negative|remove|schedule|time|when|year"},
{0xf271, false, "calendar plus|add|calendar|create|date|day|event|month|new|positive|schedule|time|when|year"},
{0xf784, false, "calendar week|date|day|detail|event|focus|month|schedule|single week|time|today|when|year"},
{0xf273, false, "calendar xmark|archive|calendar|date|day|delete|event|month|remove|schedule|time|uncheck|when|x|year"},
{0xf030, false, "camera|image|img|lens|photo|picture|record|shutter|video"},
{0xf083, false, "camera retro|camera|image|img|lens|photo|picture|record|shutter|video"},
{0xe0d8, false, "camera rotate|flip|front-facing|img|photo|selfie"},
{0xf6bb, false, "campground|camping|fall|outdoors|teepee|tent|tipi"},
{0xf786, false, "candy cane|candy|christmas|holiday|mint|peppermint|striped|xmas"},
{0xf55f, false, "cannabis|bud|chronic|drugs|endica|endo|ganja|marijuana|mary jane|pot|reefer|sativa|spliff|weed|whacky-tabacky"},
{0xf46b, false, "capsules|drugs|medicine|pills|prescription"},
{0xf1b9, false, "car|auto|automobile|car|oncoming|oncoming automobile|sedan|transportation|travel|vehicle"},
{0xf5df, false, "car battery|auto|electric|mechanic|power"},
{0xf5e1, false, "car burst|accident|auto|automobile|insurance|sedan|transportation|vehicle|wreck"},
{0xe4dd, false, "car on|alarm|car|carjack|warning"},
{0xf5de, false, "car rear|auto|automobile|sedan|transportation|travel|vehicle"},
{0xf5e4, false, "car side|auto|automobile|car|sedan|transportation|travel|vehicle"},
{0xe4de, false, "car tunnel|road|tunnel"},
{0xf8ff, false, "caravan|camper|motor home|rv|trailer|travel"},
{0xf0d7, false, "caret down|arrow|dropdown|expand|menu|more|triangle"},
{0xf0d9, false, "caret left|arrow|back|previous|triangle"},
{0xf0da, false, "caret right|arrow|forward|next|triangle"},
{0xf0d8, false, "caret up|arrow|collapse|triangle|upgrade"},
{0xf787, false, "carrot|bugs bunny|carrot|food|orange|vegan|vegetable"},
{0xf218, false, "cart arrow down|download|insert|save|shopping"},
{0xf474, false, "cart flatbed|carry|inventory|shipping|transport"},
{0xf59d, false, "cart flatbed suitcase|airport|bag|baggage|suitcase|travel"},
{0xf217, false, "cart plus|add|create|new|positive|shopping"},
{0xf07a, false, "cart shopping|buy|cart|checkout|grocery|payment|purchase|shopping|shopping cart|trolley"},
{0xf788, false, "cash register|buy|cha-ching|change|checkout|commerce|leaerboard|machine|pay|payment|purchase|store"},
{0xf6be, false, "cat|cat|feline|halloween|holiday|kitten|kitty|meow|pet"},
{0xe0df, false, "cedi sign|Cedi Sign|currency"},
{0xe3f5, false, "cent sign|Cent Sign|currency"},
{0xf0a3, false, "certificate|badge|guarantee|star|verified"},
{0xf6c0, false, "chair|chair|furniture|seat|sit"},
{0xf51b, false, "chalkboard|blackboard|learning|school|teaching|whiteboard|writing"},
{0xf51c, false, "chalkboard user|blackboard|instructor|learning|professor|school|uer|whiteboard|writing"},
{0xf79f, false, "champagne glasses|alcohol|bar|beverage|celebrate|celebration|champagne|clink|clinking glasses|drink|glass|holiday|new year's eve|party|toast"},
{0xf5e7, false, "charging station|electric|ev|tesla|vehicle"},
{0xf1fe, false, "chart area|analytics|area|chart|graph|performance|revenue|statistics"},
{0xf080, false, "chart bar|analytics|bar|chart|graph|performance|statistics"},
{0xe0e3, false, "chart column|bar|bar chart|chart|graph|performance|revenue|statistics|track|trend"},
{0xe0e4, false, "chart gantt|chart|graph|performance|statistics|track|trend"},
{0xf201, false, "chart line|activity|analytics|chart|dashboard|gain|graph|increase|line|performance|revenue|statistics"},
{0xf200, false, "chart pie|analytics|chart|diagram|graph|performance|pie|revenue|statistics"},
{0xe473, false, "chart simple|analytics|bar|chart|column|graph|performance|revenue|row|statistics|trend"},
{0xf00c, false, "check|Check Mark|accept|agree|check|check mark|checkmark|confirm|correct|coupon|done|enable|mark|notice|notification|notify|ok|select|success|tick|todo|true|validate|working|yes|✓"},
{0xf560, false, "check double|accept|agree|checkmark|confirm|correct|coupon|done|enable|notice|notification|notify|ok|select|select all|success|tick|todo|validate|working"},
{0xf772, false, "check to slot|accept|cast|election|enable|politics|positive|validate|voting|working|yes"},
{0xf7ef, false, "cheese|cheddar|curd|gouda|melt|parmesan|sandwich|swiss|wedge"},
{0xf439, false, "chess|board|castle|checkmate|game|king|rook|strategy|tournament"},
{0xf43a, false, "chess bishop|Black Chess Bishop|board|checkmate|game|strategy"},
{0xf43c, false, "chess board|board|checkmate|game|strategy"},
{0xf43f, false, "chess king|Black Chess King|board|checkmate|game|strategy"},
{0xf441, false, "chess knight|Black Chess Knight|board|checkmate|game|horse|strategy"},
{0xf443, false, "chess pawn|board|checkmate|chess|chess pawn|dupe|expendable|game|strategy"},
{0xf445, false, "chess queen|Black Chess Queen|board|checkmate|game|strategy"},
{0xf447, false, "chess rook|Black Chess Rook|board|castle|checkmate|game|strategy"},
{0xf078, false, "chevron down|arrow|download|expand|insert"},
{0xf053, false, "chevron left|Left-Pointing Angle Bracket|arrow|back|bracket|previous"},
{0xf054, false, "chevron right|Right-Pointing Angle Bracket|arrow|bracket|forward|next"},
{0xf077, false, "chevron up|arrow|collapse|upgrade|upload"},
{0xf1ae, false, "child|boy|girl|kid|toddler|uer|young|youth"},
{0xe4e0, false, "child combatant|combatant"},
{0xe59c, false, "child dress|boy|girl|kid|toddler|uer|young|youth"},
{0xe59d, false, "child reaching|boy|girl|kid|toddler|uer|young|youth"},
{0xe4e1, false, "children|boy|child|girl|kid|kids|together|uer|young|youth"},
{0xf51d, false, "church|Christian|building|cathedral|chapel|church|community|cross|religion"},
{0xf111, false, "circle|Black Circle|Black Large Circle|black circle|blue|blue circle|brown|brown circle|chart|circle|circle-thin|diameter|dot|ellipse|fill|geometric|green|green circle|notification|orange|orange circle|progress|purple|purple circle|red|red circle|round|white circle|yellow|yellow circle"},
{0xf0ab, false, "circle arrow down|download"},
{0xf0a8, false, "circle arrow left|back|previous"},
{0xf0a9, false, "circle arrow right|forward|next"},
{0xf0aa, false, "circle arrow up|upgrade|upload"},
{0xf058, false, "circle check|accept|affected|agree|clear|confirm|correct|coupon|done|enable|ok|select|success|tick|todo|validate|working|yes"},
{0xf13a, false, "circle chevron down|arrow|download|dropdown|menu|more"},
{0xf137, false, "circle chevron left|arrow|back|previous"},
{0xf138, false, "circle chevron right|arrow|forward|next"},
{0xf139, false, "circle chevron up|arrow|collapse|upgrade|upload"},
{0xf4b9, false, "circle dollar to slot|contribute|generosity|gift|give|premium"},
{0xf192, false, "circle dot|bullseye|button|geometric|notification|radio|radio button|target"},
{0xf358, false, "circle down|arrow-circle-o-down|download"},
{0xf06a, false, "circle exclamation|affect|alert|attention|damage|danger|error|failed|important|notice|notification|notify|problem|required|warning"},
{0xf47e, false, "circle h|Circled Latin Capital Letter H|clinic|covid-19|emergency|letter|map"},
{0xf042, false, "circle half stroke|Circle with Left Half Black|adjust|chart|contrast|dark|fill|light|pie|progress|saturation"},
{0xf05a, false, "circle info|details|help|information|more|support"},
{0xf359, false, "circle left|arrow-circle-o-left|back|previous"},
{0xf056, false, "circle minus|delete|hide|negative|remove|shape|trash"},
{0xe4e2, false, "circle nodes|cluster|connect|network"},
{0xf1ce, false, "circle notch|circle-o-notch|diameter|dot|ellipse|round|spinner"},
{0xf28b, false, "circle pause|hold|wait"},
{0xf144, false, "circle play|audio|music|playing|sound|start|video"},
{0xf055, false, "circle plus|add|create|expand|new|positive|shape"},
{0xf059, false, "circle question|faq|help|information|support|unknown"},
{0xf7ba, false, "circle radiation|danger|dangerous|deadly|hazard|nuclear|radioactive|sign|warning"},
{0xf35a, false, "circle right|arrow-circle-o-right|forward|next"},
{0xf28d, false, "circle stop|block|box|circle|square"},
{0xf35b, false, "circle up|arrow-circle-o-up|upgrade"},
{0xf2bd, false, "circle user|employee|uer|username|users-people"},
{0xf057, false, "circle xmark|close|cross|destroy|exit|incorrect|notice|notification|notify|problem|uncheck|wrong|x"},
{0xf64f, false, "city|buildings|busy|city|cityscape|skyscrapers|urban|windows"},
{0xe131, false, "clapperboard|camera|clapper|clapper board|director|film|movie|record"},
{0xf328, false, "clipboard|clipboar|clipboard|copy|notepad|notes|paste|record"},
{0xf46c, false, "clipboard check|accept|agree|confirm|coupon|done|enable|ok|select|success|tick|todo|validate|working|yes"},
{0xf46d, false, "clipboard list|cheatsheet|checklist|completed|done|finished|intinerary|ol|schedule|summary|tick|todo|ul|wishlist"},
{0xe4e3, false, "clipboard question|assistance|faq|interview|query|question"},
{0xf7f3, false, "clipboard user|attendance|employee|record|roster|staff|uer"},
{0xf017, false, "clock|00|4|4:00|clock|date|four|four o’clock|hour|late|minute|o'clock|o’clock|pending|schedule|ticking|time|timer|timestamp|watch"},
{0xf1da, false, "clock rotate left|Rewind|clock|pending|reverse|time|time machine|time travel|waiting"},
{0xf24d, false, "clone|arrange|copy|duplicate|paste"},
{0xf20a, false, "closed captioning|cc|deaf|hearing|subtitle|subtitling|text|video"},
{0xf0c2, false, "cloud|atmosphere|cloud|fog|overcast|save|upload|weather"},
{0xf0ed, false, "cloud arrow down|download|export|save"},
{0xf0ee, false, "cloud arrow up|import|save|upgrade|upload"},
{0xf76c, false, "cloud bolt|bolt|cloud|cloud with lightning|lightning|precipitation|rain|storm|weather"},
{0xf73b, false, "cloud meatball|FLDSMDFR|food|spaghetti|storm"},
{0xf6c3, false, "cloud moon|crescent|evening|lunar|night|partly cloudy|sky"},
{0xf73c, false, "cloud moon rain|crescent|evening|lunar|night|partly cloudy|precipitation|rain|sky|storm"},
{0xf73d, false, "cloud rain|Rain|cloud|cloud with rain|precipitation|rain|sky|storm"},
{0xf740, false, "cloud showers heavy|precipitation|rain|sky|storm"},
{0xe4e4, false, "cloud showers water|cloud|deluge|flood|rain|storm|surge"},
{0xf6c4, false, "cloud sun|clear|cloud|day|daytime|fall|outdoors|overcast|partly cloudy|sun|sun behind cloud"},
{0xf743, false, "cloud sun rain|cloud|day|overcast|precipitation|rain|storm|summer|sun|sun behind rain cloud|sunshower"},
{0xe139, false, "clover|4|charm|clover|four|four leaf clover|four-leaf clover|leaf|leprechaun|luck|lucky"},
{0xf121, false, "code|brackets|code|development|html|mysql|sql"},
{0xf126, false, "code branch|branch|git|github|mysql|rebase|sql|svn|vcs|version"},
{0xf386, false, "code commit|commit|git|github|hash|rebase|svn|vcs|version"},
{0xe13a, false, "code compare|compare|git|github|svn|version"},
{0xe13b, false, "code fork|fork|git|github|svn|version"},
{0xf387, false, "code merge|git|github|merge|pr|rebase|svn|vcs|version"},
{0xe13c, false, "code pull request|git|github|pr|svn|version"},
{0xf51e, false, "coins|currency|dime|financial|gold|money|penny|premium"},
{0xe140, false, "colon sign|Colon Sign|currency"},
{0xf075, false, "comment| conversation| discussion| talking|Right Speech Bubble|answer|bubble|chat|commenting|conversation|feedback|message|note|notification|sms|speech|talk|texting"},
{0xf651, false, "comment dollar|answer|bubble|chat|commenting|conversation|feedback|message|money|note|notification|pay|salary|sms|speech|spend|texting|transfer"},
{0xf4ad, false, "comment dots|answer|balloon|bubble|chat|comic|commenting|conversation|dialog|feedback|message|more|note|notification|reply|request|sms|speech|speech balloon|texting"},
{0xf7f5, false, "comment medical|advice|answer|bubble|chat|commenting|conversation|diagnose|feedback|message|note|notification|prescription|sms|speech|texting"},
{0xf4b3, false, "comment slash|answer|bubble|cancel|chat|commenting|conversation|disabled|feedback|message|mute|note|notification|quiet|sms|speech|texting"},
{0xf7cd, false, "comment sms|answer|chat|conversation|message|mobile|notification|phone|sms|texting"},
{0xf086, false, "comments| conversation| discussion| talking|Two Speech Bubbles|answer|bubble|chat|commenting|conversation|feedback|message|note|notification|sms|speech|talk|texting"},
{0xf653, false, "comments dollar|answer|bubble|chat|commenting|conversation|feedback|message|money|note|notification|pay|salary|sms|speech|spend|texting|transfer"},
{0xf51f, false, "compact disc|Optical Disc Icon|album|blu-ray|bluray|cd|computer|disc|disk|dvd|media|movie|music|optical|optical disk|record|video|vinyl"},
{0xf14e, false, "compass|compass|directions|directory|location|magnetic|menu|navigation|orienteering|safari|travel"},
{0xf568, false, "compass drafting|design|map|mechanical drawing|plot|plotting"},
{0xf066, false, "compress|collapse|fullscreen|minimize|move|resize|shrink|smaller"},
{0xe4e5, false, "computer|computer|desktop|display|monitor|tower"},
{0xf8cc, false, "computer mouse|click|computer|computer mouse|cursor|input|peripheral"},
{0xf563, false, "cookie|baked good|chips|chocolate|cookie|dessert|eat|snack|sweet|treat"},
{0xf564, false, "cookie bite|baked good|bitten|chips|chocolate|eat|snack|sweet|treat"},
{0xf0c5, false, "copy|clone|duplicate|file|files-o|paper|paste"},
{0xf1f9, false, "copyright|brand|c|copyright|mark|register|trademark"},
{0xf4b8, false, "couch|chair|cushion|furniture|relax|sofa"},
{0xf6c8, false, "cow|agriculture|animal|beef|bovine|co|cow|farm|fauna|livestock|mammal|milk|moo"},
{0xf09d, false, "credit card|buy|card|checkout|credit|credit card|credit-card-alt|debit|money|payment|purchase"},
{0xf125, false, "crop|design|frame|mask|modify|resize|shrink"},
{0xf565, false, "crop simple|design|frame|mask|modify|resize|shrink"},
{0xf654, false, "cross|Christian|Heavy Latin Cross|catholicism|christianity|church|cross|jesus|latin cross|religion"},
{0xf05b, false, "crosshairs|aim|bullseye|gpd|picker|position"},
{0xf520, false, "crow|bird|bullfrog|fauna|halloween|holiday|toad"},
{0xf521, false, "crown|award|clothing|crown|favorite|king|queen|royal|tiara|vip"},
{0xf7f7, false, "crutch|cane|injury|mobility|wheelchair"},
{0xe152, false, "cruzeiro sign|Cruzeiro Sign|currency"},
{0xf1b2, false, "cube|3d|block|dice|package|square|tesseract"},
{0xf1b3, false, "cubes|3d|block|dice|package|pyramid|square|stack|tesseract"},
{0xe4e6, false, "cubes stacked|blocks|cubes|sugar"},
{0x44, false, "d|Latin Capital Letter D|Latin Small Letter D|letter"},
{0xf1c0, false, "database|computer|development|directory|memory|mysql|sql|storage"},
{0xf55a, false, "delete left|Erase to the Left|command|delete|erase|keyboard|undo"},
{0xf747, false, "democrat|american|democratic party|donkey|election|left|left-wing|liberal|politics|usa"},
{0xf390, false, "desktop|computer|cpu|demo|desktop|desktop computer|device|imac|machine|monitor|pc|screen"},
{0xf655, false, "dharmachakra|Buddhist|buddhism|buddhist|dharma|religion|wheel|wheel of dharma"},
{0xe476, false, "diagram next|cells|chart|gantt|row|subtask|successor|table"},
{0xe477, false, "diagram predecessor|cells|chart|gantt|predecessor|previous|row|subtask|table"},
{0xf542, false, "diagram project|chart|graph|network|pert|statistics"},
{0xe47a, false, "diagram successor|cells|chart|gantt|next|row|subtask|successor|table"},
{0xf219, false, "diamond|ace|card|cards|diamond suit|game|gem|gemstone|poker|suit"},
{0xf5eb, false, "diamond turn right|map|navigation|sign|turn"},
{0xf522, false, "dice|chance|dice|die|gambling|game|game die|roll"},
{0xf6cf, false, "dice d20|Dungeons & Dragons|chance|d&d|dnd|fantasy|gambling|game|roll"},
{0xf6d1, false, "dice d6|Dungeons & Dragons|chance|d&d|dnd|fantasy|gambling|game|roll"},
{0xf523, false, "dice five|Die Face-5|chance|gambling|game|roll"},
{0xf524, false, "dice four|Die Face-4|chance|gambling|game|roll"},
{0xf525, false, "dice one|Die Face-1|chance|gambling|game|roll"},
{0xf526, false, "dice six|Die Face-6|chance|gambling|game|roll"},
{0xf527, false, "dice three|Die Face-3|chance|gambling|game|roll"},
{0xf528, false, "dice two|Die Face-2|chance|gambling|game|roll"},
{0xf7fa, false, "disease|bacteria|cancer|coronavirus|covid-19|flu|illness|infection|pandemic|sickness|virus"},
{0xe163, false, "display|Screen|computer|desktop|imac"},
{0xf529, false, "divide|Division Sign|arithmetic|calculus|divide|division|math|sign|÷"},
{0xf471, false, "dna|biologist|dna|double helix|evolution|gene|genetic|genetics|helix|life|molecule|protein"},
{0xf6d3, false, "dog|animal|canine|dog|fauna|mammal|pet|pooch|puppy|woof"},
{0x24, false, "dollar sign|Dollar Sign|coupon|currency|dollar|heavy dollar sign|investment|money|premium|revenue|salary"},
{0xf472, false, "dolly|carry|shipping|transport"},
{0xe169, false, "dong sign|Dong Sign|currency"},
{0xf52a, false, "door closed|doo|door|enter|exit|locked|privacy"},
{0xf52b, false, "door open|enter|exit|welcome"},
{0xf4ba, false, "dove|bird|dove|fauna|fly|flying|peace|war"},
{0xf422, false, "down left and up right to center| scale|collapse|fullscreen|minimize|move|resize|shrink|size|smaller"},
{0xf309, false, "down long|download|long-arrow-down"},
{0xf019, false, "download|export|hard drive|insert|save|transfer"},
{0xf6d5, false, "dragon|Dungeons & Dragons|d&d|dnd|dragon|fairy tale|fantasy|fire|lizard|serpent"},
{0xf5ee, false, "draw polygon|anchors|lines|object|render|shape"},
{0xf043, false, "droplet|blood|cold|color|comic|drop|droplet|raindrop|sweat|waterdrop"},
{0xf5c7, false, "droplet slash|blood|color|disabled|drop|droplet|raindrop|waterdrop"},
{0xf569, false, "drum|drum|drumsticks|instrument|music|percussion|snare|sound"},
{0xf56a, false, "drum steelpan|calypso|instrument|music|percussion|reggae|snare|sound|steel|tropical"},
{0xf6d7, false, "drumstick bite|bone|chicken|leg|meat|poultry|turkey"},
{0xf44b, false, "dumbbell|exercise|gym|strength|weight|weight-lifting|workout"},
{0xf793, false, "dumpster|alley|bin|commercial|trash|waste"},
{0xf794, false, "dumpster fire|alley|bin|commercial|danger|dangerous|euphemism|flame|heat|hot|trash|waste"},
{0xf6d9, false, "dungeon|Dungeons & Dragons|building|d&d|dnd|door|entrance|fantasy|gate"},
{0x45, false, "e|Latin Capital Letter E|Latin Small Letter E|letter"},
{0xf2a4, false, "ear deaf|ear|hearing|sign language"},
{0xf2a2, false, "ear listen|amplify|audio|deaf|ear|headset|hearing|sound"},
{0xf57c, false, "earth africa|africa|all|country|earth|europe|global|globe|gps|language|localize|location|map|online|place|planet|translate|travel|world"},
{0xf57d, false, "earth americas|all|america|country|earth|global|globe|gps|language|localize|location|map|online|place|planet|translate|travel|world"},
{0xf57e, false, "earth asia|all|asia|australia|country|earth|global|globe|gps|language|localize|location|map|online|place|planet|translate|travel|world"},
{0xf7a2, false, "earth europe|all|country|earth|europe|global|globe|gps|language|localize|location|map|online|place|planet|translate|travel|world"},
{0xe47b, false, "earth oceania|all|australia|country|earth|global|globe|gps|language|localize|location|map|melanesia|micronesia|new zealand|online|place|planet|polynesia|translate|travel|world"},
{0xf7fb, false, "egg|breakfast|chicken|easter|egg|food|shell|yolk"},
{0xf052, false, "eject|abort|cancel|cd|discharge|eject|eject button"},
{0xe16d, false, "elevator|accessibility|elevator|hoist|lift|uer|users-people"},
{0xf141, false, "ellipsis|dots|drag|kebab|list|menu|nav|navigation|ol|pacman|reorder|settings|three dots|ul"},
{0xf142, false, "ellipsis vertical|bullet|dots|drag|kebab|list|menu|nav|navigation|ol|reorder|settings|three dots|ul"},
{0xf0e0, false, "envelope|Back of Envelope|e-mail|email|envelope|letter|mail|message|newsletter|notification|offer|support"},
{0xe4e8, false, "envelope circle check|check|email|enable|envelope|mail|not affected|ok|okay|read|sent|validate|working"},
{0xf2b6, false, "envelope open|e-mail|email|letter|mail|message|newsletter|notification|offer|support"},
{0xf658, false, "envelope open text|e-mail|email|letter|mail|message|newsletter|notification|offer|support"},
{0xf674, false, "envelopes bulk|archive|envelope|letter|newsletter|offer|post office|postal|postcard|send|stamp|usps"},
{0x3d, false, "equals|Equals Sign|arithmetic|even|match|math"},
{0xf12d, false, "eraser|art|delete|remove|rubber"},
{0xf796, false, "ethernet|cable|cat 5|cat 6|connection|hardware|internet|network|wired"},
{0xf153, false, "euro sign|Euro Sign|currency"},
{0x21, false, "exclamation|!|Exclamation Mark|alert|attention|danger|error|exclamation|failed|important|mark|notice|notification|notify|outlined|problem|punctuation|red exclamation mark|required|warning|white exclamation mark"},
{0xf065, false, "expand|  maximize|  resize|  scale| arrows| bigger| enlarge| fullscreen| resize| size|expand"},
{0xe4e9, false, "explosion|blast|blowup|boom|crash|detonation|explosion"},
{0xf06e, false, "eye|body|eye|look|optic|see|seen|show|sight|views|visible"},
{0xf1fb, false, "eye dropper|beaker|clone|color|copy|eyedropper|pipette"},
{0xf2a8, false, "eye low vision|blind|eye|sight"},
{0xf070, false, "eye slash|blind|disabled|hide|show|toggle|unseen|views|visible|visiblity"},
{0x46, false, "f|Latin Capital Letter F|Latin Small Letter F|letter"},
{0xf556, false, "face angry|angry|angry face|disapprove|emoticon|face|mad|upset"},
{0xf567, false, "face dizzy|dazed|dead|disapprove|emoticon|face"},
{0xf579, false, "face flushed|dazed|embarrassed|emoticon|face|flushed|flushed face"},
{0xf119, false, "face frown|disapprove|emoticon|face|frown|frowning face|rating|sad|uer"},
{0xf57a, false, "face frown open|disapprove|emoticon|face|frown|frowning face with open mouth|mouth|open|rating|sad"},
{0xf57f, false, "face grimace|cringe|emoticon|face|grimace|grimacing face|teeth"},
{0xf580, false, "face grin|emoticon|face|grin|grinning face|laugh|smile"},
{0xf582, false, "face grin beam|emoticon|eye|face|grinning face with smiling eyes|laugh|mouth|open|smile"},
{0xf583, false, "face grin beam sweat|cold|embarass|emoticon|face|grinning face with sweat|open|smile|sweat"},
{0xf584, false, "face grin hearts|emoticon|eye|face|love|smile|smiling face with heart-eyes"},
{0xf585, false, "face grin squint|emoticon|face|grinning squinting face|laugh|mouth|satisfied|smile"},
{0xf586, false, "face grin squint tears|emoticon|face|floor|happy|laugh|rolling|rolling on the floor laughing|smile"},
{0xf587, false, "face grin stars|emoticon|eyes|face|grinning|quality|star|star-struck|starry-eyed|vip"},
{0xf588, false, "face grin tears|LOL|emoticon|face|face with tears of joy|joy|laugh|tear"},
{0xf589, false, "face grin tongue|LOL|emoticon|face|face with tongue|tongue"},
{0xf58a, false, "face grin tongue squint|LOL|emoticon|eye|face|horrible|squinting face with tongue|taste|tongue"},
{0xf58b, false, "face grin tongue wink|LOL|emoticon|eye|face|joke|tongue|wink|winking face with tongue"},
{0xf581, false, "face grin wide|emoticon|face|grinning face with big eyes|laugh|mouth|open|smile"},
{0xf58c, false, "face grin wink|emoticon|face|flirt|laugh|smile"},
{0xf596, false, "face kiss|beso|emoticon|face|kiss|kissing face|love|smooch"},
{0xf597, false, "face kiss beam|beso|emoticon|eye|face|kiss|kissing face with smiling eyes|love|smile|smooch"},
{0xf598, false, "face kiss wink heart|beso|emoticon|face|face blowing a kiss|kiss|love|smooch"},
{0xf599, false, "face laugh|LOL|emoticon|face|laugh|smile"},
{0xf59a, false, "face laugh beam|LOL|beaming face with smiling eyes|emoticon|eye|face|grin|happy|smile"},
{0xf59b, false, "face laugh squint|LOL|emoticon|face|happy|smile"},
{0xf59c, false, "face laugh wink|LOL|emoticon|face|happy|smile"},
{0xf11a, false, "face meh|deadpan|default|emoticon|face|meh|neutral|neutral face|rating|uer"},
{0xf5a4, false, "face meh blank|emoticon|face|face without mouth|mouth|neutral|quiet|rating|silent"},
{0xf5a5, false, "face rolling eyes|emoticon|eyeroll|eyes|face|face with rolling eyes|neutral|rating|rolling"},
{0xf5b3, false, "face sad cry|cry|emoticon|face|loudly crying face|sad|sob|tear|tears"},
{0xf5b4, false, "face sad tear|cry|crying face|emoticon|face|sad|tear|tears"},
{0xf118, false, "face smile|approve|default|emoticon|face|happy|rating|satisfied|slightly smiling face|smile|uer"},
{0xf5b8, false, "face smile beam|blush|emoticon|eye|face|happy|positive|smile|smiling face with smiling eyes"},
{0xf4da, false, "face smile wink|emoticon|face|happy|hint|joke|wink|winking face"},
{0xf5c2, false, "face surprise|emoticon|face|face with open mouth|mouth|open|shocked|sympathy"},
{0xf5c8, false, "face tired|angry|emoticon|face|grumpy|tired|tired face|upset"},
{0xf863, false, "fan|ac|air conditioning|blade|blower|cool|hot"},
{0xe005, false, "faucet|covid-19|drinking|drip|house|hygiene|kitchen|potable|potable water|sanitation|sink|water"},
{0xe006, false, "faucet drip|drinking|drip|house|hygiene|kitchen|potable|potable water|sanitation|sink|water"},
{0xf1ac, false, "fax|Fax Icon|business|communicate|copy|facsimile|fax|fax machine|send"},
{0xf52d, false, "feather|bird|feather|flight|light|plucked|plumage|quill|write"},
{0xf56b, false, "feather pointed|bird|light|plucked|quill|write"},
{0xe4ea, false, "ferry|barge|boat|carry|ferryboat|ship"},
{0xf15b, false, "file|Empty Document|cv|document|new|page|page facing up|pdf|resume"},
{0xf56d, false, "file arrow down|document|export|insert|save"},
{0xf574, false, "file arrow up|document|import|page|save|upgrade"},
{0xf1c7, false, "file audio|document|mp3|music|page|play|sound"},
{0xe5a0, false, "file circle check|document|enable|file|not affected|ok|okay|paper|validate|working"},
{0xe4eb, false, "file circle exclamation|document|failed|file|paper"},
{0xe4ed, false, "file circle minus|document|file|paper"},
{0xe494, false, "file circle plus|add|document|file|new|page|paper|pdf"},
{0xe4ef, false, "file circle question|document|file|paper"},
{0xe5a1, false, "file circle xmark|document|file|paper|uncheck"},
{0xf1c9, false, "file code|css|development|document|html|mysql|sql"},
{0xf56c, false, "file contract|agreement|binding|document|legal|signature|username"},
{0xf6dd, false, "file csv|document|excel|numbers|spreadsheets|table"},
{0xf1c3, false, "file excel|csv|document|numbers|spreadsheets|table"},
{0xf56e, false, "file export|download|save"},
{0xf1c5, false, "file image|Document with Picture|document|image|img|jpg|photo|png"},
{0xf56f, false, "file import|copy|document|insert|send|upload"},
{0xf570, false, "file invoice|account|bill|charge|document|payment|receipt"},
{0xf571, false, "file invoice dollar|$|account|bill|charge|document|dollar-sign|money|payment|receipt|revenue|salary|usd"},
{0xf15c, false, "file lines|Document|Document with Text|document|file-text|invoice|new|page|pdf"},
{0xf477, false, "file medical|document|health|history|prescription|record"},
{0xf1c1, false, "file pdf|acrobat|document|preview|save"},
{0xf31c, false, "file pen|edit|memo|modify|pen|pencil|update|write"},
{0xf1c4, false, "file powerpoint|display|document|keynote|presentation"},
{0xf572, false, "file prescription|document|drugs|medical|medicine|rx"},
{0xe4f0, false, "file shield|antivirus|data|document|protect|safe|safety|secure"},
{0xf573, false, "file signature|John Hancock|contract|document|name|username"},
{0xf1c8, false, "file video|document|m4v|movie|mp4|play"},
{0xf478, false, "file waveform|document|health|history|prescription|record"},
{0xf1c2, false, "file word|document|edit|page|text|writing"},
{0xf1c6, false, "file zipper|.zip|bundle|compress|compression|download|zip"},
{0xf575, false, "fill|bucket|color|paint|paint bucket"},
{0xf576, false, "fill drip|bucket|color|drop|paint|paint bucket|spill"},
{0xf008, false, "film|cinema|film|film frames|frames|movie|strip|video"},
{0xf0b0, false, "filter|funnel|options|separate|sort"},
{0xf662, false, "filter circle dollar|filter|money|options|premium|separate|sort"},
{0xe17b, false, "filter circle xmark|cancel|funnel|options|remove|separate|sort|uncheck"},
{0xf577, false, "fingerprint|human|id|identification|lock|privacy|smudge|touch|unique|unlock"},
{0xf06d, false, "fire|burn|caliente|fire|flame|heat|hot|popular|tool"},
{0xe4f1, false, "fire burner|cook|fire|flame|kitchen|stove"},
{0xf134, false, "fire extinguisher|burn|caliente|extinguish|fire|fire extinguisher|fire fighter|flame|heat|hot|quench|rescue"},
{0xf7e4, false, "fire flame curved|burn|caliente|flame|heat|hot|popular"},
{0xf46a, false, "fire flame simple|caliente|energy|fire|flame|gas|heat|hot"},
{0xf578, false, "fish|Pisces|fauna|fish|gold|seafood|swimming|zodiac"},
{0xe4f2, false, "fish fins|fish|fishery|pisces|seafood"},
{0xf024, false, "flag|black flag|country|notice|notification|notify|pole|report|symbol|waving"},
{0xf11e, false, "flag checkered|checkered|chequered|chequered flag|finish|notice|notification|notify|pole|racing|report|start|symbol|win"},
{0xf74d, false, "flag usa|betsy ross|country|fla|flag: United States|old glory|stars|stripes|symbol"},
{0xf0c3, false, "flask|beaker|chemicals|experiment|experimental|knowledge|labs|liquid|potion|science|vial"},
{0xe4f3, false, "flask vial| beaker| chemicals| experiment| experimental| labs| liquid| science| vial|ampule|chemistry|lab|laboratory|potion|test|test tube"},
{0xf0c7, false, "floppy disk|Black Hard Shell Floppy Disk|computer|disk|download|floppy|floppy disk|floppy-o"},
{0xe184, false, "florin sign|currency"},
{0xf07b, false, "folder|Black Folder|archive|directory|document|file|file folder|folder"},
{0xe185, false, "folder closed|file"},
{0xf65d, false, "folder minus|archive|delete|directory|document|file|negative|remove"},
{0xf07c, false, "folder open|Open Folder|archive|directory|document|empty|file|folder|new|open|open file folder"},
{0xf65e, false, "folder plus|add|archive|create|directory|document|file|new|positive"},
{0xf802, false, "folder tree|archive|directory|document|file|search|structure"},
{0xf031, false, "font|alphabet|glyph|text|type|typeface"},
{0xf2b4, false, "font awesome|awesome|flag|font|icons|typeface"},
{0xf44e, false, "football|american|american football|ball|fall|football|nfl|pigskin|seasonal"},
{0xf04e, false, "forward|arrow|double|fast|fast-forward button|forward|next|skip"},
{0xf050, false, "forward fast|arrow|end|last|next|next scene|next track|next track button|quick|triangle"},
{0xf051, false, "forward step|end|last|next"},
{0xe18f, false, "franc sign|French Franc Sign|currency"},
{0xf52e, false, "frog|amphibian|bullfrog|fauna|hop|kermit|kiss|prince|ribbit|toad|wart"},
{0xf1e3, false, "futbol|ball|football|mls|soccer|soccer ball"},
{0x47, false, "g|Latin Capital Letter G|Latin Small Letter G|letter"},
{0xf11b, false, "gamepad|arcade|controller|d-pad|joystick|playstore|video|video game"},
{0xf52f, false, "gas pump|car|diesel|fuel|fuel pump|fuelpump|gas|gasoline|petrol|pump|station"},
{0xf624, false, "gauge|dashboard|fast|odometer|speed|speedometer"},
{0xf625, false, "gauge high|dashboard|fast|odometer|quick|speed|speedometer"},
{0xf629, false, "gauge simple|dashboard|fast|odometer|speed|speedometer"},
{0xf62a, false, "gauge simple high|dashboard|fast|odometer|quick|speed|speedometer"},
{0xf0e3, false, "gavel|hammer|judge|law|lawyer|opinion"},
{0xf013, false, "gear|cog|cogwheel|configuration|gear|mechanical|modify|settings|sprocket|tool|wheel"},
{0xf085, false, "gears|configuration|gears|mechanical|modify|settings|sprocket|wheel"},
{0xf3a5, false, "gem|diamond|gem|gem stone|jewel|jewelry|sapphire|stone|treasure"},
{0xf22d, false, "genderless|androgynous|asexual|gender|sexless"},
{0xf6e2, false, "ghost|apparition|blinky|clyde|creature|face|fairy tale|fantasy|floating|ghost|halloween|holiday|inky|monster|pacman|pinky|spirit"},
{0xf06b, false, "gift|box|celebration|christmas|generosity|gift|giving|holiday|party|present|wrapped|wrapped gift|xmas"},
{0xf79c, false, "gifts|christmas|generosity|giving|holiday|party|present|wrapped|xmas"},
{0xe4f4, false, "glass water|potable|water"},
{0xe4f5, false, "glass water droplet|potable|water"},
{0xf530, false, "glasses|hipster|nerd|reading|sight|spectacles|vision"},
{0xf0ac, false, "globe|all|coordinates|country|earth|global|globe|globe with meridians|gps|internet|language|localize|location|map|meridians|network|online|place|planet|translate|travel|world|www"},
{0xf450, false, "golf ball tee|caddy|eagle|putt|tee"},
{0xf664, false, "gopuram|building|entrance|hinduism|temple|tower"},
{0xf19d, false, "graduation cap|cap|celebration|ceremony|clothing|college|graduate|graduation|graduation cap|hat|learning|school|student"},
{0x3e, false, "greater than|Greater-Than Sign|arithmetic|compare|math"},
{0xf532, false, "greater than equal|arithmetic|compare|math"},
{0xf58d, false, "grip|affordance|drag|drop|grab|handle"},
{0xf7a4, false, "grip lines|affordance|drag|drop|grab|handle"},
{0xf7a5, false, "grip lines vertical|affordance|drag|drop|grab|handle"},
{0xf58e, false, "grip vertical|affordance|drag|drop|grab|handle"},
{0xe4f6, false, "group arrows rotate|community|engagement|spin|sync"},
{0xe19a, false, "guarani sign|Guarani Sign|currency"},
{0xf7a6, false, "guitar|acoustic|instrument|music|rock|rock and roll|song|strings"},
{0xe19b, false, "gun|firearm|pistol|weapon"},
{0x48, false, "h|Latin Capital Letter H|Latin Small Letter H|letter"},
{0xf6e3, false, "hammer|admin|configuration|equipment|fix|hammer|maintenance|modify|recovery|repair|settings|tool"},
{0xf665, false, "hamsa|amulet|christianity|islam|jewish|judaism|muslim|protection"},
{0xf256, false, "hand|Raised Hand|backhand|game|halt|palm|raised|raised back of hand|request|roshambo|stop"},
{0xf255, false, "hand back fist|fist|game|roshambo"},
{0xf461, false, "hand dots|allergy|freckles|hand|hives|palm|pox|skin|spots"},
{0xf6de, false, "hand fist|Dungeons & Dragons|clenched|d&d|dnd|fantasy|fist|hand|ki|monk|punch|raised fist|resist|strength|unarmed combat"},
{0xf4bd, false, "hand holding|carry|lift"},
{0xf4c0, false, "hand holding dollar|$|carry|coupon|dollar sign|donate|donation|giving|investment|lift|money|premium|price|revenue|salary"},
{0xf4c1, false, "hand holding droplet|blood|carry|covid-19|drought|grow|lift|sanitation"},
{0xe4f7, false, "hand holding hand|care|give|help|hold|protect"},
{0xf4be, false, "hand holding heart|carry|charity|gift|lift|package|wishlist"},
{0xe05c, false, "hand holding medical|care|covid-19|donate|help"},
{0xf258, false, "hand lizard|game|roshambo"},
{0xf806, false, "hand middle finger|finger|flip the bird|gesture|hand|hate|middle finger|rude"},
{0xf25b, false, "hand peace|hand|rest|truce|v|victory|victory hand"},
{0xf0a7, false, "hand point down|finger|hand-o-down|point"},
{0xf0a5, false, "hand point left|back|finger|hand-o-left|left|point|previous"},
{0xf0a4, false, "hand point right|finger|forward|hand-o-right|next|point|right"},
{0xf0a6, false, "hand point up|finger|hand|hand-o-up|index|index pointing up|point|request|up|upgrade"},
{0xf25a, false, "hand pointer|arrow|cursor|select"},
{0xf257, false, "hand scissors|cut|game|roshambo"},
{0xe05d, false, "hand sparkles|clean|covid-19|hygiene|magic|palm|soap|wash"},
{0xf259, false, "hand spock|finger|hand|live long|palm|prosper|salute|spock|star trek|vulcan|vulcan salute"},
{0xe4f8, false, "handcuffs|arrest|criminal|handcuffs|jail|lock|police|wrist"},
{0xf2a7, false, "hands|Translate|asl|deaf|hands"},
{0xf2a3, false, "hands asl interpreting|asl|deaf|finger|hand|interpret|speak"},
{0xe4f9, false, "hands bound|abduction|bound|handcuff|wrist"},
{0xe05e, false, "hands bubbles|covid-19|hygiene|soap|wash"},
{0xe1a8, false, "hands clapping|applause|clap|clapping hands|hand"},
{0xf4c2, false, "hands holding|carry|hold|lift"},
{0xe4fa, false, "hands holding child|care|give|help|hold|parent|protect"},
{0xe4fb, false, "hands holding circle|circle|gift|protection"},
{0xf684, false, "hands praying|kneel|preach|religion|worship"},
{0xf2b5, false, "handshake|agreement|greeting|meeting|partnership"},
{0xf4c4, false, "handshake angle|aid|assistance|handshake|partnership|volunteering"},
{0xf4c6, false, "handshake simple|agreement|greeting|hand|handshake|meeting|partnership|shake"},
{0xe05f, false, "handshake simple slash|broken|covid-19|disabled|social distance"},
{0xe060, false, "handshake slash|broken|covid-19|disabled|social distance"},
{0xf6e6, false, "hanukiah|candelabrum|candle|candlestick|hanukkah|jewish|judaism|light|menorah|religion"},
{0xf0a0, false, "hard drive|Hard Disk|cpu|hard drive|harddrive|machine|save|storage"},
{0x23, false, "hashtag|Number Sign|Twitter|instagram|pound|social media|tag"},
{0xf8c0, false, "hat cowboy|buckaroo|horse|jackeroo|john b.|old west|pardner|ranch|rancher|rodeo|western|wrangler"},
{0xf8c1, false, "hat cowboy side|buckaroo|horse|jackeroo|john b.|old west|pardner|ranch|rancher|rodeo|western|wrangler"},
{0xf6e8, false, "hat wizard|Dungeons & Dragons|accessory|buckle|clothing|d&d|dnd|fantasy|halloween|head|holiday|mage|magic|pointy|witch"},
{0xe061, false, "head side cough|cough|covid-19|germs|lungs|respiratory|sick|uer"},
{0xe062, false, "head side cough slash|cough|covid-19|disabled|germs|lungs|respiratory|sick|uer"},
{0xe063, false, "head side mask|breath|coronavirus|covid-19|filter|flu|infection|pandemic|respirator|uer|virus"},
{0xe064, false, "head side virus|cold|coronavirus|covid-19|flu|infection|pandemic|sick|uer"},
{0xf1dc, false, "heading|format|header|text|title"},
{0xf025, false, "headphones|audio|earbud|headphone|listen|music|sound|speaker"},
{0xf58f, false, "headphones simple|audio|listen|music|sound|speaker"},
{0xf590, false, "headset|audio|gamer|gaming|listen|live chat|microphone|shot caller|sound|support|telemarketer"},
{0xf004, false, "heart|ace|black|black heart|blue|blue heart|brown|brown heart|card|evil|favorite|game|green|green heart|heart|heart suit|like|love|orange|orange heart|purple|purple heart|red heart|relationship|valentine|white|white heart|wicked|wishlist|yellow|yellow heart"},
{0xe4fc, false, "heart circle bolt|cardiogram|ekg|electric|heart|love|pacemaker"},
{0xe4fd, false, "heart circle check|enable|favorite|heart|love|not affected|ok|okay|validate|working"},
{0xe4fe, false, "heart circle exclamation|failed|favorite|heart|love"},
{0xe4ff, false, "heart circle minus|favorite|heart|love"},
{0xe500, false, "heart circle plus|favorite|heart|love"},
{0xe501, false, "heart circle xmark|favorite|heart|love|uncheck"},
{0xf7a9, false, "heart crack|break|breakup|broken|broken heart|crushed|dislike|dumped|grief|love|lovesick|relationship|sad"},
{0xf21e, false, "heart pulse|ekg|electrocardiogram|health|lifeline|vital signs"},
{0xf533, false, "helicopter|airwolf|apache|chopper|flight|fly|helicopter|travel|vehicle"},
{0xe502, false, "helicopter symbol|chopper|helicopter|landing pad|whirlybird"},
{0xf807, false, "helmet safety|construction|hardhat|helmet|maintenance|safety"},
{0xe503, false, "helmet un|helmet|united nations"},
{0xf591, false, "highlighter|edit|marker|modify|sharpie|update|write"},
{0xe507, false, "hill avalanche|mudslide|snow|winter"},
{0xe508, false, "hill rockslide|mudslide"},
{0xf6ed, false, "hippo|animal|fauna|hippo|hippopotamus|hungry|mammal"},
{0xf453, false, "hockey puck|ice|nhl|sport"},
{0xf7aa, false, "holly berry|catwoman|christmas|decoration|flora|halle|holiday|ororo munroe|plant|storm|xmas"},
{0xf6f0, false, "horse|equestrian|equus|fauna|horse|mammmal|mare|neigh|pony|racehorse|racing"},
{0xf7ab, false, "horse head|equus|fauna|mammmal|mare|neigh|pony"},
{0xf0f8, false, "hospital|building|covid-19|doctor|emergency room|hospital|medical center|medicine"},
{0xf80d, false, "hospital user|covid-19|doctor|network|patient|primary care|uer"},
{0xf593, false, "hot tub person|jacuzzi|spa|uer"},
{0xf80f, false, "hotdog|bun|chili|frankfurt|frankfurter|hot dog|hotdog|kosher|polish|sandwich|sausage|vienna|weiner"},
{0xf594, false, "hotel|building|hotel|inn|lodging|motel|resort|travel"},
{0xf254, false, "hourglass|hour|hourglass|hourglass not done|minute|sand|stopwatch|time|timer"},
{0xf253, false, "hourglass end|hour|hourglass done|minute|pending|sand|stopwatch|time|timer|waiting"},
{0xf252, false, "hourglass half|hour|minute|pending|sand|stopwatch|time|waiting"},
{0xf251, false, "hourglass start|hour|minute|sand|stopwatch|time|waiting"},
{0xf015, false, "house|abode|building|home|house|main|residence"},
{0xe3af, false, "house chimney|abode|building|chimney|house|main|residence|smokestack"},
{0xf6f1, false, "house chimney crack|building|devastation|disaster|earthquake|home|insurance"},
{0xf7f2, false, "house chimney medical|covid-19|doctor|general practitioner|hospital|infirmary|medicine|office|outpatient"},
{0xe065, false, "house chimney user|covid-19|home|isolation|quarantine|uer"},
{0xe00d, false, "house chimney window|abode|building|family|home|residence"},
{0xe509, false, "house circle check|abode|enable|home|house|not affected|ok|okay|validate|working"},
{0xe50a, false, "house circle exclamation|abode|affected|failed|home|house"},
{0xe50b, false, "house circle xmark|abode|destroy|home|house|uncheck"},
{0xe3b1, false, "house crack|building|devastation|disaster|earthquake|home|insurance"},
{0xe50c, false, "house fire|burn|emergency|home"},
{0xe50d, false, "house flag|camp|home"},
{0xe50e, false, "house flood water|damage|flood|water"},
{0xe50f, false, "house flood water circle arrow right|damage|flood|water"},
{0xe066, false, "house laptop|computer|covid-19|device|office|remote|work from home"},
{0xe510, false, "house lock|closed|home|house|lockdown|padlock|privacy|quarantine"},
{0xe3b2, false, "house medical|covid-19|doctor|facility|general practitioner|health|hospital|infirmary|medicine|office|outpatient"},
{0xe511, false, "house medical circle check|clinic|enable|hospital|not affected|ok|okay|validate|working"},
{0xe512, false, "house medical circle exclamation|affected|clinic|failed|hospital"},
{0xe513, false, "house medical circle xmark|clinic|destroy|hospital|uncheck"},
{0xe514, false, "house medical flag|clinic|hospital|mash"},
{0xe012, false, "house signal|abode|building|connect|family|home|residence|smart home|wifi|www"},
{0xe515, false, "house tsunami|damage|flood|tidal wave|wave"},
{0xe1b0, false, "house user|house|uer"},
{0xf6f2, false, "hryvnia sign|Hryvnia Sign|currency"},
{0xf751, false, "hurricane|coriolis effect|eye|storm|tropical cyclone|typhoon"},
{0x49, false, "i|Latin Capital Letter I|Latin Small Letter I|letter"},
{0xf246, false, "i cursor|editing|i-beam|type|writing"},
{0xf810, false, "ice cream|chocolate|cone|cream|dessert|frozen|ice|ice cream|scoop|sorbet|sweet|vanilla|yogurt"},
{0xf7ad, false, "icicles|cold|frozen|hanging|ice|seasonal|sharp"},
{0xf86d, false, "icons|bolt|category|emoji|heart|image|music|photo|symbols"},
{0xf2c1, false, "id badge|address|contact|identification|license|profile|uer|username"},
{0xf2c2, false, "id card|contact|demographics|document|identification|issued|profile|registration|uer|username"},
{0xf47f, false, "id card clip|contact|demographics|document|identification|issued|profile|uer|username"},
{0xf7ae, false, "igloo|dome|dwelling|eskimo|home|house|ice|snow"},
{0xf03e, false, "image|album|img|landscape|photo|picture"},
{0xf3e0, false, "image portrait|id|image|img|photo|picture|selfie|uer|username"},
{0xf302, false, "images|album|img|landscape|photo|picture"},
{0xf01c, false, "inbox|archive|desk|email|mail|message"},
{0xf03c, false, "indent|align|justify|paragraph|tab"},
{0xe1bc, false, "indian rupee sign|Indian Rupee Sign|currency"},
{0xf275, false, "industry|building|factory|industrial|manufacturing|mill|warehouse"},
{0xf534, false, "infinity|Infinity|eternity|forever|infinity|math|unbounded|universal"},
{0xf129, false, "info|details|help|information|more|support"},
{0xf033, false, "italic|edit|emphasis|font|format|text|type"},
{0x4a, false, "j|Latin Capital Letter J|Latin Small Letter J|letter"},
{0xe516, false, "jar|jam|jelly|storage"},
{0xe517, false, "jar wheat|flour|storage"},
{0xf669, false, "jedi|crest|force|sith|skywalker|star wars|yoda"},
{0xf0fb, false, "jet fighter|airforce|airplane|airport|fast|fly|goose|marines|maverick|military|plane|quick|top gun|transportation|travel"},
{0xe518, false, "jet fighter up|airforce|airplane|airport|fast|fly|goose|marines|maverick|military|plane|quick|top gun|transportation|travel"},
{0xf595, false, "joint|blunt|cannabis|doobie|drugs|marijuana|roach|smoke|smoking|spliff"},
{0xe519, false, "jug detergent|detergent|laundry|soap|wash"},
{0x4b, false, "k|Latin Capital Letter K|Latin Small Letter K|letter"},
{0xf66b, false, "kaaba|Muslim|building|cube|islam|kaaba|muslim|religion"},
{0xf084, false, "key|key|lock|password|private|secret|unlock"},
{0xf11c, false, "keyboard|accessory|computer|edit|input|keyboard|text|type|write"},
{0xf66d, false, "khanda|Adi Shakti|chakkar|sikh|sikhism|sword"},
{0xe1c4, false, "kip sign|Kip Sign|currency"},
{0xf479, false, "kit medical|emergency|emt|health|medical|rescue"},
{0xe51a, false, "kitchen set|chef|cook|cup|kitchen|pan|pot|skillet"},
{0xf535, false, "kiwi bird|bird|fauna|new zealand"},
{0x4c, false, "l|Latin Capital Letter L|Latin Small Letter L|letter"},
{0xe51b, false, "land mine on|bomb|danger|explosion|war"},
{0xf66f, false, "landmark|building|classical|historic|memorable|monument|museum|politics|society"},
{0xf752, false, "landmark dome|building|historic|memorable|monument|politics"},
{0xe51c, false, "landmark flag|capitol|flag|landmark|memorial"},
{0xf1ab, false, "language|dialect|idiom|localize|speech|translate|vernacular"},
{0xf109, false, "laptop|computer|cpu|dell|demo|device|fabook|fb|laptop|mac|macbook|machine|pc|personal"},
{0xf5fc, false, "laptop code|computer|cpu|dell|demo|develop|device|fabook|fb|mac|macbook|machine|mysql|pc|sql"},
{0xe51d, false, "laptop file|computer|education|laptop|learning|remote work"},
{0xf812, false, "laptop medical|computer|device|ehr|electronic health records|history"},
{0xe1c8, false, "lari sign|Lari Sign|currency"},
{0xf5fd, false, "layer group|arrange|category|develop|layers|map|platform|stack"},
{0xf06c, false, "leaf|eco|flora|nature|plant|vegan"},
{0xf30a, false, "left long|back|long-arrow-left|previous"},
{0xf337, false, "left right|arrow|arrows-h|expand|horizontal|landscape|left-right arrow|resize|wide"},
{0xf094, false, "lemon|citrus|fruit|lemon|lemonade|lime|tart"},
{0x3c, false, "less than|Less-Than Sign|arithmetic|compare|math"},
{0xf537, false, "less than equal|arithmetic|compare|math"},
{0xf1cd, false, "life ring|coast guard|help|overboard|save|support"},
{0xf0eb, false, "lightbulb|  comic|  electric|  idea|  innovation|  inspiration|  light|  light bulb| bulb|bulb|comic|electric|energy|idea|inspiration|mechanical"},
{0xe51e, false, "lines leaning|canted|domino|falling|resilience|resilient|tipped"},
{0xf0c1, false, "link|attach|attachment|chain|connect|lin|link"},
{0xf127, false, "link slash|attachment|chain|chain-broken|disabled|disconnect|remove"},
{0xf195, false, "lira sign|Lira Sign|currency"},
{0xf03a, false, "list|bullet|category|cheatsheet|checklist|completed|done|finished|ol|summary|todo|ul"},
{0xf0ae, false, "list check|bullet|cheatsheet|checklist|downloading|downloads|enable|loading|progress|project management|settings|summary|to do|validate|working"},
{0xf0cb, false, "list ol|cheatsheet|checklist|completed|done|finished|numbers|ol|summary|todo|ul"},
{0xf0ca, false, "list ul|bullet|cheatsheet|checklist|completed|done|finished|ol|summary|todo|ul"},
{0xe1d3, false, "litecoin sign|currency"},
{0xf124, false, "location arrow|address|compass|coordinate|direction|gps|map|navigation|place"},
{0xf601, false, "location crosshairs|address|coordinate|direction|gps|location|map|navigation|place|where"},
{0xf3c5, false, "location dot|address|coordinates|destination|gps|localize|location|map|navigation|paper|pin|place|point of interest|position|route|travel"},
{0xf041, false, "location pin|address|coordinates|destination|gps|localize|location|map|navigation|paper|pin|place|point of interest|position|route|travel"},
{0xe51f, false, "location pin lock|closed|lockdown|map|padlock|privacy|quarantine"},
{0xf023, false, "lock|admin|closed|lock|locked|open|padlock|password|privacy|private|protect|security"},
{0xf3c1, false, "lock open|admin|lock|open|padlock|password|privacy|private|protect|security|unlock"},
{0xe520, false, "locust|horde|infestation|locust|plague|swarm"},
{0xf604, false, "lungs|air|breath|covid-19|exhalation|inhalation|lungs|organ|respiration|respiratory"},
{0xe067, false, "lungs virus|breath|coronavirus|covid-19|flu|infection|pandemic|respiratory|sick"},
{0x4d, false, "m|Latin Capital Letter M|Latin Small Letter M|letter"},
{0xf076, false, "magnet|Attract|attraction|horseshoe|lodestone|magnet|magnetic|tool"},
{0xf002, false, "magnifying glass|bigger|enlarge|equipment|find|glass|inspection|magnifier|magnify|magnifying|magnifying glass tilted left|preview|search|tool|zoom"},
{0xe521, false, "magnifying glass arrow right|find|magnifier|next|search"},
{0xe522, false, "magnifying glass chart| data| graph| intelligence|analysis|chart|magnifier|market|revenue"},
{0xf688, false, "magnifying glass dollar|bigger|enlarge|find|magnifier|magnify|money|preview|zoom"},
{0xf689, false, "magnifying glass location|bigger|enlarge|find|magnifier|magnify|preview|zoom"},
{0xf010, false, "magnifying glass minus|magnifier|minify|negative|smaller|zoom|zoom out"},
{0xf00e, false, "magnifying glass plus|bigger|enlarge|magnifier|magnify|positive|zoom|zoom in"},
{0xe1d5, false, "manat sign|Manat Sign|currency"},
{0xf279, false, "map|address|coordinates|destination|gps|localize|location|map|navigation|paper|pin|place|point of interest|position|route|travel|world|world map"},
{0xf59f, false, "map location|address|coordinates|destination|gps|localize|location|map|navigation|paper|pin|place|point of interest|position|route|travel"},
{0xf5a0, false, "map location dot|address|coordinates|destination|gps|localize|location|map|navigation|paper|pin|place|point of interest|position|route|travel"},
{0xf276, false, "map pin|address|agree|coordinates|destination|gps|localize|location|map|marker|navigation|pin|place|position|pushpin|round pushpin|travel"},
{0xf5a1, false, "marker|design|edit|modify|sharpie|update|write"},
{0xf222, false, "mars|gender|male|male sign|man"},
{0xf224, false, "mars and venus|Male and Female Sign|female|gender|intersex|male|transgender"},
{0xe523, false, "mars and venus burst|gender|uer|violence"},
{0xf227, false, "mars double|Doubled Male Sign|gay|gender|male|men"},
{0xf229, false, "mars stroke|Male with Stroke Sign|gender|transgender"},
{0xf22b, false, "mars stroke right|Horizontal Male with Stroke Sign|gender"},
{0xf22a, false, "mars stroke up|Vertical Male with Stroke Sign|gender"},
{0xf57b, false, "martini glass|alcohol|bar|beverage|cocktail|cocktail glass|drink|glass|liquor"},
{0xf561, false, "martini glass citrus|alcohol|beverage|drink|gin|glass|margarita|martini|vodka"},
{0xf000, false, "martini glass empty|alcohol|bar|beverage|drink|liquor"},
{0xf6fa, false, "mask|carnivale|costume|disguise|halloween|secret|super hero"},
{0xe1d7, false, "mask face|breath|coronavirus|covid-19|filter|flu|infection|pandemic|respirator|virus"},
{0xe524, false, "mask ventilator|breath|gas|mask|oxygen|respirator|ventilator"},
{0xf630, false, "masks theater|art|comedy|mask|perform|performing|performing arts|theater|theatre|tragedy"},
{0xe525, false, "mattress pillow|air mattress|mattress|pillow|rest|sleep"},
{0xf31e, false, "maximize|  maximize|  resize|  scale| arrows| bigger| enlarge| fullscreen| resize| size|expand"},
{0xf5a2, false, "medal|award|guarantee|medal|quality|ribbon|sports medal|star|trophy|warranty"},
{0xf538, false, "memory|DIMM|RAM|hardware|storage|technology"},
{0xf676, false, "menorah|candle|hanukkah|jewish|judaism|light"},
{0xf223, false, "mercury|Mercury|gender|hybrid|transgender"},
{0xf27a, false, "message| conversation| discussion| talking|answer|bubble|chat|commenting|conversation|feedback|message|note|notification|sms|speech|talk|texting"},
{0xf753, false, "meteor|armageddon|asteroid|comet|shooting star|space"},
{0xf2db, false, "microchip|cpu|hardware|processor|technology"},
{0xf130, false, "microphone|address|audio|information|podcast|public|record|sing|sound|talking|voice"},
{0xf3c9, false, "microphone lines|audio|mic|microphone|music|podcast|record|sing|sound|studio|studio microphone|talking|voice"},
{0xf539, false, "microphone lines slash|audio|disable|disabled|disconnect|disconnect|mute|podcast|record|sing|sound|voice"},
{0xf131, false, "microphone slash|audio|disable|disabled|mute|podcast|record|sing|sound|voice"},
{0xf610, false, "microscope|covid-19|electron|knowledge|lens|microscope|optics|science|shrink|testing|tool"},
{0xe1ed, false, "mill sign|Mill Sign|currency"},
{0xf78c, false, "minimize|collapse|fullscreen|minimize|move|resize|shrink|smaller"},
{0xf068, false, "minus|En Dash|Minus Sign|collapse|delete|hide|math|minify|minus|negative|remove|sign|trash|−"},
{0xf7b5, false, "mitten|clothing|cold|glove|hands|knitted|seasonal|warmth"},
{0xf3ce, false, "mobile|android|call|cell|cell phone|device|mobile|mobile phone|number|phone|screen|telephone|text"},
{0xf10b, false, "mobile button|apple|call|cell phone|device|iphone|number|screen|telephone"},
{0xe527, false, "mobile retro|cellphone|cellular|phone"},
{0xf3cf, false, "mobile screen|android|call|cell phone|device|number|screen|telephone|text"},
{0xf3cd, false, "mobile screen button|apple|call|cell phone|device|iphone|number|screen|telephone"},
{0xf0d6, false, "money bill|buy|cash|checkout|coupon|investment|money|payment|premium|price|purchase|revenue|salary"},
{0xf3d1, false, "money bill 1|buy|cash|checkout|money|payment|premium|price|purchase|salary"},
{0xf53b, false, "money bill 1 wave|buy|cash|checkout|money|payment|premium|price|purchase|salary"},
{0xe528, false, "money bill transfer|bank|conversion|deposit|investment|money|salary|transfer|withdrawal"},
{0xe529, false, "money bill trend up|bank|bonds|inflation|investment|market|revenue|salary|stocks|trade"},
{0xf53a, false, "money bill wave|buy|cash|checkout|money|payment|premium|price|purchase|salary"},
{0xe52a, false, "money bill wheat|agribusiness|agriculture|farming|food|investment|livelihood|subsidy"},
{0xe1f3, false, "money bills|atm|cash|investment|money|moolah|premium|revenue|salary"},
{0xf53c, false, "money check|bank check|buy|checkout|cheque|money|payment|price|purchase|salary"},
{0xf53d, false, "money check dollar|bank check|buy|checkout|cheque|money|payment|price|purchase|salary"},
{0xf5a6, false, "monument|building|historic|landmark|memorable"},
{0xf186, false, "moon|Power Sleep Symbol|contrast|crescent|crescent moon|dark|lunar|moon|night"},
{0xf5a7, false, "mortar pestle|crush|culinary|grind|medical|mix|pharmacy|prescription|spices"},
{0xf678, false, "mosque|Muslim|building|islam|landmark|mosque|muslim|religion"},
{0xe52b, false, "mosquito|bite|bug|mosquito|west nile"},
{0xe52c, false, "mosquito net|bite|malaria|mosquito|net"},
{0xf21c, false, "motorcycle|bike|machine|motorcycle|racing|transportation|vehicle"},
{0xe52d, false, "mound|barrier|hill|pitcher|speedbump"},
{0xf6fc, false, "mountain|cold|glacier|hiking|hill|landscape|mountain|snow|snow-capped mountain|travel|view"},
{0xe52e, false, "mountain city|location|rural|urban"},
{0xe52f, false, "mountain sun|country|hiking|landscape|rural|travel|view"},
{0xf7b6, false, "mug hot|beverage|caliente|cocoa|coffee|cup|drink|holiday|hot|hot beverage|hot chocolate|steam|steaming|tea|warmth"},
{0xf0f4, false, "mug saucer|beverage|breakfast|cafe|drink|fall|morning|mug|seasonal|tea"},
{0xf001, false, "music|lyrics|melody|music|musical note|note|sing|sound"},
{0x4e, false, "n|Latin Capital Letter N|Latin Small Letter N|letter|nay|no"},
{0xe1f6, false, "naira sign|Naira Sign|currency"},
{0xf6ff, false, "network wired|computer|connect|ethernet|internet|intranet"},
{0xf22c, false, "neuter|Neuter|gender"},
{0xf1ea, false, "newspaper|article|editorial|headline|journal|journalism|news|newsletter|newspaper|paper|press"},
{0xf53e, false, "not equal|arithmetic|compare|math"},
{0xe1fe, false, "notdef|404|close|missing|not found"},
{0xf249, false, "note sticky|message|note|paper|reminder|sticker"},
{0xf481, false, "notes medical|clipboard|doctor|ehr|health|history|records"},
{0x4f, false, "o|Latin Capital Letter O|Latin Small Letter O|letter"},
{0xf247, false, "object group|combine|copy|design|merge|select"},
{0xf248, false, "object ungroup|copy|design|merge|select|separate"},
{0xf613, false, "oil can|auto|crude|gasoline|grease|lubricate|petroleum"},
{0xe532, false, "oil well|drill|oil|rig"},
{0xf679, false, "om|Hindu|buddhism|hinduism|jainism|mantra|om|religion"},
{0xf700, false, "otter|animal|badger|fauna|fishing|fur|mammal|marten|otter|playful"},
{0xf03b, false, "outdent|align|justify|paragraph|tab"},
{0x50, false, "p|Latin Capital Letter P|Latin Small Letter P|letter"},
{0xf815, false, "pager|beeper|cell phone|communication|page|pager"},
{0xf5aa, false, "paint roller|acrylic|art|brush|color|fill|maintenance|paint|pigment|watercolor"},
{0xf1fc, false, "paintbrush|acrylic|art|brush|color|fill|modify|paint|paintbrush|painting|pigment|watercolor"},
{0xf53f, false, "palette|acrylic|art|artist palette|brush|color|fill|museum|paint|painting|palette|pigment|watercolor"},
{0xf482, false, "pallet|archive|box|inventory|shipping|warehouse"},
{0xe209, false, "panorama|image|img|landscape|photo|wide"},
{0xf1d8, false, "paper plane|air|float|fold|mail|paper|send"},
{0xf0c6, false, "paperclip|attach|attachment|connect|link|papercli|paperclip"},
{0xf4cd, false, "parachute box|aid|assistance|goods|relief|rescue|supplies"},
{0xf1dd, false, "paragraph|Pilcrow Sign|edit|format|text|writing"},
{0xf5ab, false, "passport|document|id|identification|issued|travel"},
{0xf0ea, false, "paste|clipboard|copy|document|paper"},
{0xf04c, false, "pause|bar|double|hold|pause|pause button|vertical|wait"},
{0xf1b0, false, "paw|animal|cat|dog|pet|print"},
{0xf67c, false, "peace|peace|peace symbol|serenity|tranquility|truce|war"},
{0xf304, false, "pen|ballpoint|design|edit|modify|pen|update|write"},
{0xf305, false, "pen clip|design|edit|modify|update|write"},
{0xf5ac, false, "pen fancy|black nib|design|edit|fountain|fountain pen|modify|nib|pen|update|write"},
{0xf5ad, false, "pen nib|design|edit|fountain pen|modify|update|write"},
{0xf5ae, false, "pen ruler|design|draft|draw|maintenance|modify|pencil"},
{0xf044, false, "pen to square|edit|modify|pen|pencil|update|write"},
{0xf303, false, "pencil|Lower Left Pencil|design|draw|edit|lead|maintenance|modify|pencil|update|write"},
{0xe068, false, "people arrows| conversation| discussion| talking|distance|insert|isolation|separate|social distancing|talk|together|uer|users-people"},
{0xf4ce, false, "people carry box|together|uer|users-people"},
{0xe533, false, "people group|crowd|family|group|team|together|uer"},
{0xe534, false, "people line|crowd|group|need|together|uer"},
{0xe535, false, "people pulling|forced return|together|uer|yanking"},
{0xe536, false, "people robbery|criminal|hands up|looting|robbery|steal|uer"},
{0xe537, false, "people roof|crowd|family|group|manage|people|safe|shelter|together|uer"},
{0xf816, false, "pepper hot|buffalo wings|capsicum|chili|chilli|habanero|hot|hot pepper|jalapeno|mexican|pepper|spicy|tabasco|vegetable"},
{0x25, false, "percent|Percent Sign|discount|fraction|proportion|rate|ratio"},
{0xf183, false, "person|default|man|person standing|stand|standing|uer|woman"},
{0xe538, false, "person arrow down to line|ground|indigenous|insert|native|uer"},
{0xe539, false, "person arrow up from line|population|rise|uer|upgrade"},
{0xf84a, false, "person biking|bicycle|bike|biking|cyclist|pedal|person biking|summer|uer|wheel"},
{0xf756, false, "person booth|changing room|curtain|uer|vote|voting"},
{0xe53a, false, "person breastfeeding|baby|child|infant|mother|nutrition|parent|sustenance|uer"},
{0xe53b, false, "person burst|abuse|accident|crash|explode|uer|violence"},
{0xe53c, false, "person cane|aging|cane|elderly|old|staff|uer"},
{0xe53d, false, "person chalkboard|blackboard|instructor|keynote|lesson|presentation|teacher|uer"},
{0xe53e, false, "person circle check|approved|enable|not affected|ok|okay|uer|validate|working"},
{0xe53f, false, "person circle exclamation|affected|alert|failed|lost|missing|uer"},
{0xe540, false, "person circle minus|delete|remove|uer"},
{0xe541, false, "person circle plus|add|follow|found|uer"},
{0xe542, false, "person circle question|faq|lost|missing|request|uer"},
{0xe543, false, "person circle xmark|dead|removed|uer|uncheck"},
{0xf85e, false, "person digging|bury|construction|debris|dig|maintenance|men at work|uer"},
{0xf470, false, "person dots from line|allergy|diagnosis|uer"},
{0xf182, false, "person dress|man|skirt|uer|woman"},
{0xe544, false, "person dress burst|abuse|accident|crash|explode|uer|violence"},
{0xe545, false, "person drowning|drown|emergency|swim|uer"},
{0xe546, false, "person falling|accident|fall|trip|uer"},
{0xe547, false, "person falling burst|accident|crash|death|fall|homicide|murder|uer"},
{0xe548, false, "person half dress|gender|man|restroom|transgender|uer|woman"},
{0xe549, false, "person harassing|abuse|scream|shame|shout|uer|yell"},
{0xf6ec, false, "person hiking|autumn|fall|follow|hike|mountain|outdoors|summer|uer|walk"},
{0xe54a, false, "person military pointing|army|customs|guard|uer"},
{0xe54b, false, "person military rifle|armed forces|army|military|rifle|uer|war"},
{0xe54c, false, "person military to person|civilian|coordination|military|uer"},
{0xf683, false, "person praying|kneel|place of worship|religion|thank|uer|worship"},
{0xe31e, false, "person pregnant|baby|birth|child|parent|pregnant|pregnant woman|uer|woman"},
{0xe54d, false, "person rays|affected|focus|shine|uer"},
{0xe54e, false, "person rifle|army|combatant|gun|military|rifle|uer|war"},
{0xf70c, false, "person running|exit|flee|follow|marathon|person running|race|running|uer|workout"},
{0xe54f, false, "person shelter|house|inside|roof|safe|safety|shelter|uer"},
{0xf7c5, false, "person skating|figure skating|ice|olympics|rink|skate|uer|winter"},
{0xf7c9, false, "person skiing|downhill|olympics|ski|skier|snow|uer|winter"},
{0xf7ca, false, "person skiing nordic|cross country|olympics|uer|winter"},
{0xf7ce, false, "person snowboarding|olympics|ski|snow|snowboard|snowboarder|uer|winter"},
{0xf5c4, false, "person swimming|ocean|person swimming|pool|sea|swim|uer|water"},
{0xe5a9, false, "person through window|door|exit|forced entry|leave|robbery|steal|uer|window"},
{0xf554, false, "person walking|crosswalk|exercise|follow|hike|move|person walking|uer|walk|walking|workout"},
{0xe551, false, "person walking arrow loop left|follow|population return|return|uer"},
{0xe552, false, "person walking arrow right|exit|follow|internally displaced|leave|refugee|uer"},
{0xe553, false, "person walking dashed line arrow right|exit|follow|refugee|uer"},
{0xe554, false, "person walking luggage|bag|baggage|briefcase|carry-on|deployment|follow|rolling|uer"},
{0xf29d, false, "person walking with cane|blind|cane|follow|uer"},
{0xe221, false, "peseta sign|Peseta Sign|currency"},
{0xe222, false, "peso sign|Peso Sign|currency"},
{0xf095, false, "phone|Left Hand Telephone Receiver|call|earphone|number|phone|receiver|support|talking|telephone|telephone receiver|voice"},
{0xf879, false, "phone flip|Right Hand Telephone Receiver|call|earphone|number|support|telephone|voice"},
{0xf3dd, false, "phone slash|call|cancel|disabled|disconnect|earphone|mute|number|support|telephone|voice"},
{0xf2a0, false, "phone volume|call|earphone|number|sound|support|talking|telephone|voice|volume-control-phone"},
{0xf87c, false, "photo film|av|film|image|library|media"},
{0xf4d3, false, "piggy bank|bank|salary|save|savings"},
{0xf484, false, "pills|drugs|medicine|prescription|tablets"},
{0xf818, false, "pizza slice|cheese|chicago|italian|mozzarella|new york|pepperoni|pie|slice|teenage mutant ninja turtles|tomato"},
{0xf67f, false, "place of worship|building|church|holy|mosque|synagogue"},
{0xf072, false, "plane|airplane|airport|destination|fly|location|mode|travel|trip"},
{0xf5af, false, "plane arrival|aeroplane|airplane|airplane arrival|airport|arrivals|arriving|destination|fly|land|landing|location|mode|travel|trip"},
{0xe555, false, "plane circle check|airplane|airport|enable|flight|fly|not affected|ok|okay|travel|validate|working"},
{0xe556, false, "plane circle exclamation|affected|airplane|airport|failed|flight|fly|travel"},
{0xe557, false, "plane circle xmark|airplane|airport|destroy|flight|fly|travel|uncheck"},
{0xf5b0, false, "plane departure|aeroplane|airplane|airplane departure|airport|check-in|departing|departure|departures|destination|fly|location|mode|take off|taking off|travel|trip"},
{0xe558, false, "plane lock|airplane|airport|closed|flight|fly|lockdown|padlock|privacy|quarantine|travel"},
{0xe069, false, "plane slash|airplane mode|airport|canceled|covid-19|delayed|disabled|grounded|travel"},
{0xe22d, false, "plane up|airplane|airport|internet|signal|sky|wifi|wireless"},
{0xe5aa, false, "plant wilt|drought|planting|vegetation|wilt"},
{0xe55a, false, "plate wheat|bowl|hunger|rations|wheat"},
{0xf04b, false, "play|arrow|audio|music|play|play button|playing|right|sound|start|triangle|video"},
{0xf1e6, false, "plug|connect|electric|electric plug|electricity|online|plug|power"},
{0xe55b, false, "plug circle bolt|electric|electricity|plug|power"},
{0xe55c, false, "plug circle check|electric|electricity|enable|not affected|ok|okay|plug|power|validate|working"},
{0xe55d, false, "plug circle exclamation|affected|electric|electricity|failed|plug|power"},
{0xe55e, false, "plug circle minus|disconnect|electric|electricity|plug|power"},
{0xe55f, false, "plug circle plus|electric|electricity|plug|power"},
{0xe560, false, "plug circle xmark|destroy|disconnect|electric|electricity|outage|plug|power|uncheck"},
{0x2b, false, "plus|+|Plus Sign|add|create|expand|follow|math|modify|new|plus|positive|shape|sign"},
{0xe43c, false, "plus minus|Plus-Minus Sign|add|math|subtract"},
{0xf2ce, false, "podcast|audio|broadcast|music|sound"},
{0xf2fe, false, "poo|crap|dung|face|monster|pile of poo|poo|poop|shit|smile|turd|uer"},
{0xf75a, false, "poo storm|bolt|cloud|euphemism|lightning|mess|poop|shit|turd"},
{0xf619, false, "poop|crap|poop|shit|smile|turd"},
{0xf011, false, "power off|Power Symbol|cancel|computer|on|reboot|restart"},
{0xf5b1, false, "prescription|drugs|medical|medicine|pharmacy|rx"},
{0xf485, false, "prescription bottle|drugs|medical|medicine|pharmacy|rx"},
{0xf486, false, "prescription bottle medical|drugs|medical|medicine|pharmacy|rx"},
{0xf02f, false, "print|Print Screen Symbol|Printer Icon|business|computer|copy|document|office|paper|printer"},
{0xe06a, false, "pump medical|anti-bacterial|clean|covid-19|disinfect|hygiene|medical grade|sanitizer|soap"},
{0xe06b, false, "pump soap|anti-bacterial|clean|covid-19|disinfect|hygiene|sanitizer|soap"},
{0xf12e, false, "puzzle piece|add-on|addon|clue|game|interlocking|jigsaw|piece|puzzle|puzzle piece|section"},
{0x51, false, "q|Latin Capital Letter Q|Latin Small Letter Q|letter"},
{0xf029, false, "qrcode|barcode|info|information|scan"},
{0x3f, false, "question|?|Question Mark|faq|help|information|mark|outlined|punctuation|question|red question mark|request|support|unknown|white question mark"},
{0xf10d, false, "quote left|Left Double Quotation Mark|mention|note|phrase|text|type"},
{0xf10e, false, "quote right|Right Double Quotation Mark|mention|note|phrase|text|type"},
{0x52, false, "r|Latin Capital Letter R|Latin Small Letter R|letter"},
{0xf7b9, false, "radiation|danger|dangerous|deadly|hazard|nuclear|radioactive|warning"},
{0xf8d7, false, "radio|am|broadcast|fm|frequency|music|news|radio|receiver|transmitter|tuner|video"},
{0xf75b, false, "rainbow|gold|leprechaun|prism|rain|rainbow|sky"},
{0xe561, false, "ranking star|chart|first place|podium|quality|rank|revenue|win"},
{0xf543, false, "receipt|accounting|bookkeeping|check|coupon|evidence|invoice|money|pay|proof|receipt|table"},
{0xf8d9, false, "record vinyl|LP|album|analog|music|phonograph|sound"},
{0xf641, false, "rectangle ad|advertisement|media|newspaper|promotion|publicity"},
{0xf022, false, "rectangle list|cheatsheet|checklist|completed|done|finished|ol|summary|todo|ul"},
{0xf410, false, "rectangle xmark|browser|cancel|computer|development|uncheck"},
{0xf1b8, false, "recycle|Recycling Symbol For Generic Materials|Universal Recycling Symbol|Waste|compost|garbage|recycle|recycling symbol|reuse|trash"},
{0xf25d, false, "registered|copyright|mark|r|registered|trademark"},
{0xf363, false, "repeat|arrow|clockwise|flip|reload|renew|repeat|repeat button|retry|rewind|switch"},
{0xf3e5, false, "reply|mail|message|respond"},
{0xf122, false, "reply all|mail|message|respond"},
{0xf75e, false, "republican|american|conservative|election|elephant|politics|republican party|right|right-wing|usa"},
{0xf7bd, false, "restroom|bathroom|toilet|uer|water closet|wc"},
{0xf079, false, "retweet|refresh|reload|renew|retry|share|swap"},
{0xf4d6, false, "ribbon|badge|cause|celebration|lapel|pin|reminder|reminder ribbon|ribbon"},
{0xf2f5, false, "right from bracket|arrow|exit|leave|log out|logout|sign-out"},
{0xf362, false, "right left|arrow|arrows|exchange|reciprocate|return|swap|transfer"},
{0xf30b, false, "right long|forward|long-arrow-right|next"},
{0xf2f6, false, "right to bracket|arrow|enter|join|log in|login|sign in|sign up|sign-in|signin|signup"},
{0xf70b, false, "ring|Dungeons & Dragons|Gollum|band|binding|d&d|dnd|engagement|fantasy|gold|jewelry|marriage|precious|premium"},
{0xf018, false, "road|highway|map|motorway|pavement|road|route|street|travel"},
{0xe562, false, "road barrier|block|border|no entry|roadblock"},
{0xe563, false, "road bridge|bridge|infrastructure|road|travel"},
{0xe564, false, "road circle check|enable|freeway|highway|not affected|ok|okay|pavement|road|validate|working"},
{0xe565, false, "road circle exclamation|affected|failed|freeway|highway|pavement|road"},
{0xe566, false, "road circle xmark|destroy|freeway|highway|pavement|road|uncheck"},
{0xe567, false, "road lock|closed|freeway|highway|lockdown|padlock|pavement|privacy|quarantine|road"},
{0xe568, false, "road spikes|barrier|roadblock|spikes"},
{0xf544, false, "robot|android|automate|computer|cyborg|face|monster|robot"},
{0xf135, false, "rocket|aircraft|app|jet|launch|nasa|space"},
{0xf2f1, false, "rotate|arrow|clockwise|exchange|modify|refresh|reload|renew|retry|rotate|swap|withershins"},
{0xf2ea, false, "rotate left|back|control z|exchange|oops|return|swap"},
{0xf2f9, false, "rotate right|forward|refresh|reload|renew|repeat|retry"},
{0xf4d7, false, "route|directions|navigation|travel"},
{0xf09e, false, "rss|blog|feed|journal|news|writing"},
{0xf158, false, "ruble sign|Ruble Sign|currency"},
{0xe569, false, "rug|blanket|carpet|rug|textile"},
{0xf545, false, "ruler|design|draft|length|measure|planning|ruler|straight edge|straight ruler"},
{0xf546, false, "ruler combined|design|draft|length|measure|planning"},
{0xf547, false, "ruler horizontal|design|draft|length|measure|planning"},
{0xf548, false, "ruler vertical|design|draft|length|measure|planning"},
{0xf156, false, "rupee sign|Rupee Sign|currency"},
{0xe23d, false, "rupiah sign|currency"},
{0x53, false, "s|Latin Capital Letter S|Latin Small Letter S|letter"},
{0xf81d, false, "sack dollar|bag|burlap|cash|dollar|investment|money|money bag|moneybag|premium|robber|salary|santa|usd"},
{0xe56a, false, "sack xmark|bag|burlap|coupon|rations|salary|uncheck"},
{0xe445, false, "sailboat|dinghy|mast|sailboat|sailing|yacht"},
{0xf7bf, false, "satellite|communications|hardware|orbit|satellite|space"},
{0xf7c0, false, "satellite dish|SETI|antenna|communications|dish|hardware|radar|receiver|satellite|satellite antenna|saucer|signal|space"},
{0xf24e, false, "scale balanced|Libra|balance|balance scale|balanced|justice|law|legal|measure|rule|scale|weight|zodiac"},
{0xf515, false, "scale unbalanced|justice|legal|measure|unbalanced|weight"},
{0xf516, false, "scale unbalanced flip|justice|legal|measure|unbalanced|weight"},
{0xf549, false, "school|building|education|learn|school|student|teacher"},
{0xe56b, false, "school circle check|enable|not affected|ok|okay|schoolhouse|validate|working"},
{0xe56c, false, "school circle exclamation|affected|failed|schoolhouse"},
{0xe56d, false, "school circle xmark|destroy|schoolhouse|uncheck"},
{0xe56e, false, "school flag|educate|flag|school|schoolhouse"},
{0xe56f, false, "school lock|closed|lockdown|padlock|privacy|quarantine|schoolhouse"},
{0xf0c4, false, "scissors|Black Safety Scissors|White Scissors|clip|cutting|equipment|modify|scissors|snip|tool"},
{0xf54a, false, "screwdriver|admin|configuration|equipment|fix|maintenance|mechanic|modify|repair|screw|screwdriver|settings|tool"},
{0xf7d9, false, "screwdriver wrench|admin|configuration|equipment|fix|maintenance|modify|repair|screwdriver|settings|tools|wrench"},
{0xf70e, false, "scroll|Dungeons & Dragons|announcement|d&d|dnd|fantasy|paper|scholar|script|scroll"},
{0xf6a0, false, "scroll torah|book|jewish|judaism|religion|scroll"},
{0xf7c2, false, "sd card|image|img|memory|photo|save"},
{0xe447, false, "section|Section Sign|law|legal|silcrow"},
{0xf4d8, false, "seedling|environment|flora|grow|investment|plant|sapling|seedling|vegan|young"},
{0xf233, false, "server|computer|cpu|database|hardware|mysql|network|sql"},
{0xf61f, false, "shapes|blocks|build|circle|square|triangle"},
{0xf064, false, "share|forward|save|send|social"},
{0xf14d, false, "share from square|forward|save|send|social"},
{0xf1e0, false, "share nodes|forward|save|send|social"},
{0xe571, false, "sheet plastic|plastic|plastic wrap|protect|tarp|tarpaulin|waterproof"},
{0xf20b, false, "shekel sign|New Sheqel Sign|currency|ils|money"},
{0xf132, false, "shield|achievement|armor|award|block|cleric|defend|defense|holy|paladin|protect|safety|security|shield|weapon|winner"},
{0xe572, false, "shield cat|animal|feline|pet|protect|safety|veterinary"},
{0xe573, false, "shield dog|animal|canine|pet|protect|safety|veterinary"},
{0xf3ed, false, "shield halved|achievement|armor|award|block|cleric|defend|defense|holy|paladin|privacy|security|shield|weapon|winner"},
{0xe574, false, "shield heart|love|protect|safe|safety|shield|wishlist"},
{0xe06c, false, "shield virus|antibodies|barrier|coronavirus|covid-19|flu|health|infection|pandemic|protect|safety|vaccine"},
{0xf21a, false, "ship|boat|passenger|sea|ship|water"},
{0xf553, false, "shirt|clothing|fashion|garment|shirt|short sleeve|t-shirt|tshirt"},
{0xf54b, false, "shoe prints|feet|footprints|steps|walk"},
{0xf54f, false, "shop|bodega|building|buy|market|purchase|shopping|store"},
{0xe4a5, false, "shop lock|bodega|building|buy|closed|lock|lockdown|market|padlock|privacy|purchase|quarantine|shop|shopping|store"},
{0xe070, false, "shop slash|building|buy|closed|covid-19|disabled|purchase|shopping"},
{0xf2cc, false, "shower|bath|clean|faucet|shower|water"},
{0xe448, false, "shrimp|allergy|crustacean|prawn|seafood|shellfish|shrimp|tail"},
{0xf074, false, "shuffle|arrow|arrows|crossed|shuffle|shuffle tracks button|sort|swap|switch|transfer"},
{0xf197, false, "shuttle space|astronaut|machine|nasa|rocket|space|transportation"},
{0xf4d9, false, "sign hanging|directions|real estate|signage|wayfinding"},
{0xf012, false, "signal|antenna|antenna bars|bar|bars|cell|graph|mobile|online|phone|reception|status"},
{0xf5b7, false, "signature|John Hancock|cursive|name|username|writing"},
{0xf277, false, "signs post|directions|directory|map|signage|wayfinding"},
{0xf7c4, false, "sim card|hard drive|hardware|portable|storage|technology|tiny"},
{0xe06d, false, "sink|bathroom|covid-19|faucet|kitchen|wash"},
{0xf0e8, false, "sitemap|directory|hierarchy|ia|information architecture|organization"},
{0xf54c, false, "skull|bones|death|face|fairy tale|monster|skeleton|skull|uer|x-ray|yorick"},
{0xf714, false, "skull crossbones|Black Skull and Crossbones|Dungeons & Dragons|alert|bones|crossbones|d&d|danger|dangerous area|dead|deadly|death|dnd|face|fantasy|halloween|holiday|jolly-roger|monster|pirate|poison|skeleton|skull|skull and crossbones|warning"},
{0xf715, false, "slash|cancel|close|mute|off|stop|x"},
{0xf7cc, false, "sleigh|christmas|claus|fly|holiday|santa|sled|snow|xmas"},
{0xf1de, false, "sliders|adjust|configuration|modify|settings|sliders|toggle"},
{0xf75f, false, "smog|dragon|fog|haze|pollution|smoke|weather"},
{0xf48d, false, "smoking|cancer|cigarette|nicotine|smoking|smoking status|tobacco"},
{0xf2dc, false, "snowflake|Heavy Chevron Snowflake|cold|precipitation|rain|snow|snowfall|snowflake|winter"},
{0xf7d0, false, "snowman|cold|decoration|frost|frosty|holiday|snow|snowman|snowman without snow"},
{0xf7d2, false, "snowplow|clean up|cold|road|storm|winter"},
{0xe06e, false, "soap|bar|bathing|bubbles|clean|cleaning|covid-19|hygiene|lather|soap|soapdish|wash"},
{0xf696, false, "socks|business socks|business time|clothing|feet|flight of the conchords|socks|stocking|wednesday"},
{0xf5ba, false, "solar panel|clean|eco-friendly|energy|green|sun"},
{0xf0dc, false, "sort|filter|order"},
{0xf0dd, false, "sort down|arrow|descending|filter|insert|order|sort-desc"},
{0xf0de, false, "sort up|arrow|ascending|filter|order|sort-asc|upgrade"},
{0xf5bb, false, "spa|flora|massage|mindfulness|plant|wellness"},
{0xf67b, false, "spaghetti monster flying|agnosticism|atheism|flying spaghetti monster|fsm"},
{0xf891, false, "spell check|dictionary|edit|editor|enable|grammar|text|validate|working"},
{0xf717, false, "spider|arachnid|bug|charlotte|crawl|eight|halloween|insect|spider"},
{0xf110, false, "spinner|circle|loading|pending|progress"},
{0xf5bc, false, "splotch|Ink|blob|blotch|glob|stain"},
{0xf2e5, false, "spoon|cutlery|dining|scoop|silverware|spoon|tableware"},
{0xf5bd, false, "spray can|Paint|aerosol|design|graffiti|tag"},
{0xf5d0, false, "spray can sparkles|car|clean|deodorize|fresh|pine|scent"},
{0xf0c8, false, "square|Black Square|black medium square|block|box|geometric|shape|square|white medium square"},
{0xf14c, false, "square arrow up right|diagonal|new|open|send|share"},
{0xf150, false, "square caret down|arrow|caret-square-o-down|dropdown|expand|insert|menu|more|triangle"},
{0xf191, false, "square caret left|arrow|back|caret-square-o-left|previous|triangle"},
{0xf152, false, "square caret right|arrow|caret-square-o-right|forward|next|triangle"},
{0xf151, false, "square caret up|arrow|caret-square-o-up|collapse|triangle|upgrade|upload"},
{0xf14a, false, "square check|accept|agree|box|button|check|check box with check|check mark button|checkmark|confirm|correct|coupon|done|enable|mark|ok|select|success|tick|todo|validate|working|yes|✓"},
{0xf199, false, "square envelope|e-mail|email|letter|mail|message|notification|offer|support"},
{0xf45c, false, "square full|black large square|block|blue|blue square|box|brown|brown square|geometric|green|green square|orange|orange square|purple|purple square|red|red square|shape|square|white large square|yellow|yellow square"},
{0xf0fd, false, "square h|directions|emergency|hospital|hotel|letter|map"},
{0xf146, false, "square minus|collapse|delete|hide|minify|negative|remove|shape|trash"},
{0xe576, false, "square nfi|non-food item|supplies"},
{0xf540, false, "square parking|auto|car|garage|meter|parking"},
{0xf14b, false, "square pen|edit|modify|pencil-square|update|write"},
{0xe577, false, "square person confined|captivity|confined|uer"},
{0xf098, false, "square phone|call|earphone|number|support|telephone|voice"},
{0xf87b, false, "square phone flip|call|earphone|number|support|telephone|voice"},
{0xf0fe, false, "square plus|add|create|expand|new|positive|shape"},
{0xf682, false, "square poll horizontal|chart|graph|results|statistics|survey|trend|vote|voting"},
{0xf681, false, "square poll vertical|chart|graph|results|revenue|statistics|survey|trend|vote|voting"},
{0xf698, false, "square root variable|arithmetic|calculus|division|math"},
{0xf143, false, "square rss|blog|feed|journal|news|writing"},
{0xf1e1, false, "square share nodes|forward|save|send|social"},
{0xf360, false, "square up right|arrow|diagonal|direction|external-link-square|intercardinal|new|northeast|open|share|up-right arrow"},
{0xe578, false, "square virus|coronavirus|covid-19|disease|flu|infection|pandemic"},
{0xf2d3, false, "square xmark|close|cross|cross mark button|incorrect|mark|notice|notification|notify|problem|square|uncheck|window|wrong|x|×"},
{0xe579, false, "staff snake|asclepius|asklepian|health|serpent|wellness"},
{0xe289, false, "stairs|exit|steps|up"},
{0xf5bf, false, "stamp|art|certificate|imprint|rubber|seal"},
{0xe5af, false, "stapler|desktop|milton|office|paperclip|staple"},
{0xf005, false, "star|achievement|award|favorite|important|night|quality|rating|score|star|vip"},
{0xf699, false, "star and crescent|Muslim|islam|muslim|religion|star and crescent"},
{0xf089, false, "star half|achievement|award|rating|score|star-half-empty|star-half-full"},
{0xf5c0, false, "star half stroke|achievement|award|rating|score|star-half-empty|star-half-full"},
{0xf69a, false, "star of david|David|Jew|Jewish|jewish|judaism|religion|star|star of David"},
{0xf621, false, "star of life|doctor|emt|first aid|health|medical"},
{0xf154, false, "sterling sign|Pound Sign|currency"},
{0xf0f1, false, "stethoscope|covid-19|diagnosis|doctor|general practitioner|heart|hospital|infirmary|medicine|office|outpatient|stethoscope"},
{0xf04d, false, "stop|block|box|square|stop|stop button"},
{0xf2f2, false, "stopwatch|clock|reminder|stopwatch|time|waiting"},
{0xe06f, false, "stopwatch 20|ABCs|countdown|covid-19|happy birthday|i will survive|reminder|seconds|time|timer"},
{0xf54e, false, "store|bodega|building|buy|market|purchase|shopping|store"},
{0xe071, false, "store slash|building|buy|closed|covid-19|disabled|purchase|shopping"},
{0xf21d, false, "street view|directions|location|map|navigation|uer"},
{0xf0cc, false, "strikethrough|cancel|edit|font|format|modify|text|type"},
{0xf551, false, "stroopwafel|caramel|cookie|dessert|sweets|waffle"},
{0xf12c, false, "subscript|edit|font|format|text|type"},
{0xf0f2, false, "suitcase|baggage|luggage|move|packing|suitcase|travel|trip"},
{0xf0fa, false, "suitcase medical|first aid|firstaid|health|help|medical|supply|support"},
{0xf5c1, false, "suitcase rolling|baggage|luggage|move|suitcase|travel|trip"},
{0xf185, false, "sun|bright|brighten|contrast|day|lighter|rays|sol|solar|star|sun|sunny|weather"},
{0xe57a, false, "sun plant wilt|arid|droop|drought"},
{0xf12b, false, "superscript|edit|exponential|font|format|text|type"},
{0xf5c3, false, "swatchbook|Pantone|color|design|hue|palette"},
{0xf69b, false, "synagogue|Jew|Jewish|building|jewish|judaism|religion|star of david|synagogue|temple"},
{0xf48e, false, "syringe|covid-19|doctor|immunizations|medical|medicine|needle|shot|sick|syringe|vaccinate|vaccine"},
{0x54, false, "t|Latin Capital Letter T|Latin Small Letter T|letter"},
{0xf0ce, false, "table|category|data|excel|spreadsheet"},
{0xf00a, false, "table cells|blocks|boxes|category|grid|squares"},
{0xf009, false, "table cells large|blocks|boxes|category|grid|squares"},
{0xf0db, false, "table columns|browser|category|dashboard|organize|panes|split"},
{0xf00b, false, "table list|category|cheatsheet|checklist|completed|done|finished|ol|summary|todo|ul"},
{0xf45d, false, "table tennis paddle ball|ball|bat|game|paddle|ping pong|table tennis"},
{0xf3fb, false, "tablet|device|kindle|screen"},
{0xf10a, false, "tablet button|apple|device|ipad|kindle|screen"},
{0xf3fa, false, "tablet screen button|apple|device|ipad|kindle|screen"},
{0xf490, false, "tablets|drugs|medicine|pills|prescription"},
{0xf566, false, "tachograph digital|data|distance|speed|tachometer"},
{0xf02b, false, "tag|discount|labe|label|price|shopping"},
{0xf02c, false, "tags|discount|label|price|shopping"},
{0xf4db, false, "tape|design|package|sticky"},
{0xe57b, false, "tarp|protection|tarp|tent|waterproof"},
{0xe57c, false, "tarp droplet|protection|tarp|tent|waterproof"},
{0xf1ba, false, "taxi|cab|cabbie|car|car service|lyft|machine|oncoming|oncoming taxi|taxi|transportation|travel|uber|vehicle"},
{0xf62e, false, "teeth|bite|dental|dentist|gums|mouth|smile|tooth"},
{0xf62f, false, "teeth open|dental|dentist|gums bite|mouth|smile|tooth"},
{0xe03f, false, "temperature arrow down|air conditioner|cold|heater|mercury|thermometer|winter"},
{0xe040, false, "temperature arrow up|air conditioner|cold|heater|mercury|thermometer|winter"},
{0xf2cb, false, "temperature empty|cold|mercury|status|temperature"},
{0xf2c7, false, "temperature full|fever|hot|mercury|status|temperature"},
{0xf2c9, false, "temperature half|mercury|status|temperature|thermometer|weather"},
{0xf769, false, "temperature high|cook|covid-19|mercury|summer|thermometer|warm"},
{0xf76b, false, "temperature low|cold|cool|covid-19|mercury|thermometer|winter"},
{0xf2ca, false, "temperature quarter|mercury|status|temperature"},
{0xf2c8, false, "temperature three quarters|mercury|status|temperature"},
{0xf7d7, false, "tenge sign|Tenge Sign|currency"},
{0xe57d, false, "tent|bivouac|campground|campsite|refugee|shelter|tent"},
{0xe57e, false, "tent arrow down to line| bivouac| campground| refugee| shelter| tent|campsite|permanent|refugee|shelter"},
{0xe57f, false, "tent arrow left right| bivouac| campground| refugee| shelter| tent|campsite|refugee|shelter|transition"},
{0xe580, false, "tent arrow turn left| bivouac| campground| refugee| shelter| tent|campsite|refugee|shelter|temporary"},
{0xe581, false, "tent arrows down| bivouac| campground| refugee| shelter| tent|campsite|insert|refugee|shelter|spontaneous"},
{0xe582, false, "tents| bivouac| campground| refugee| shelter| tent|bivouac|campground|campsite|refugee|shelter|tent"},
{0xf120, false, "terminal|code|coding|command|console|development|prompt|terminal"},
{0xf034, false, "text height|edit|font|format|modify|text|type"},
{0xf87d, false, "text slash|cancel|disabled|font|format|remove|style|text"},
{0xf035, false, "text width|edit|font|format|modify|text|type"},
{0xf491, false, "thermometer|covid-19|mercury|status|temperature"},
{0xf165, false, "thumbs down|-1|disagree|disapprove|dislike|down|hand|social|thumb|thumbs down|thumbs-o-down"},
{0xf164, false, "thumbs up|+1|agree|approve|favorite|hand|like|ok|okay|social|success|thumb|thumbs up|thumbs-o-up|up|yes|you got it dude"},
{0xf08d, false, "thumbtack|Black Pushpin|coordinates|location|marker|pin|pushpin|thumb-tack"},
{0xf145, false, "ticket|admission|admission tickets|coupon|movie|pass|support|ticket|voucher"},
{0xf3ff, false, "ticket simple|admission|coupon|movie|pass|support|ticket|voucher"},
{0xe29c, false, "timeline|chronological|deadline|history|linear"},
{0xf204, false, "toggle off|button|off|on|switch"},
{0xf205, false, "toggle on|button|off|on|switch"},
{0xf7d8, false, "toilet|bathroom|flush|john|loo|pee|plumbing|poop|porcelain|potty|restroom|throne|toile|toilet|washroom|waste|wc"},
{0xf71e, false, "toilet paper|bathroom|covid-19|halloween|holiday|lavatory|paper towels|prank|privy|restroom|roll|roll of paper|toilet|toilet paper|wipe"},
{0xe072, false, "toilet paper slash|bathroom|covid-19|disabled|halloween|holiday|lavatory|leaves|prank|privy|restroom|roll|toilet|trouble|ut oh|wipe"},
{0xe583, false, "toilet portable|outhouse|toilet"},
{0xe584, false, "toilets portable|outhouse|toilet"},
{0xf552, false, "toolbox|admin|chest|configuration|container|equipment|fix|maintenance|mechanic|modify|repair|settings|tool|toolbox|tools"},
{0xf5c9, false, "tooth|bicuspid|dental|dentist|molar|mouth|teeth|tooth"},
{0xf6a1, false, "torii gate|building|religion|shinto|shinto shrine|shintoism|shrine"},
{0xf76f, false, "tornado|cloud|cyclone|dorothy|landspout|tornado|toto|twister|vortext|waterspout|weather|whirlwind"},
{0xf519, false, "tower broadcast|airwaves|antenna|communication|emergency|radio|reception|waves"},
{0xe585, false, "tower cell|airwaves|antenna|communication|radio|reception|waves"},
{0xe586, false, "tower observation|fire tower|view"},
{0xf722, false, "tractor|agriculture|farm|tractor|vehicle"},
{0xf25c, false, "trademark|copyright|mark|register|symbol|tm|trade mark|trademark"},
{0xf637, false, "traffic light|direction|light|road|signal|traffic|travel|vertical traffic light"},
{0xe041, false, "trailer|carry|haul|moving|travel"},
{0xf238, false, "train|bullet|commute|locomotive|railway|subway|train"},
{0xf239, false, "train subway|machine|railway|train|transportation|vehicle"},
{0xe5b4, false, "train tram|crossing|machine|mountains|seasonal|tram|transportation|trolleybus"},
{0xf225, false, "transgender|female|gender|intersex|male|transgender|transgender symbol"},
{0xf1f8, false, "trash|delete|garbage|hide|remove"},
{0xf829, false, "trash arrow up|back|control z|delete|garbage|hide|oops|remove|undo|upgrade"},
{0xf2ed, false, "trash can|delete|garbage|hide|remove|trash-o"},
{0xf82a, false, "trash can arrow up|back|control z|delete|garbage|hide|oops|remove|undo|upgrade"},
{0xf1bb, false, "tree|bark|evergreen tree|fall|flora|forest|investment|nature|plant|seasonal|tree"},
{0xe587, false, "tree city|building|city|urban"},
{0xf071, false, "triangle exclamation|alert|attention|danger|error|failed|important|notice|notification|notify|problem|required|warnin|warning"},
{0xf091, false, "trophy|achievement|award|cup|game|prize|trophy|winner"},
{0xe589, false, "trowel|build|construction|equipment|maintenance|tool"},
{0xe58a, false, "trowel bricks|build|construction|maintenance|reconstruction|tool"},
{0xf0d1, false, "truck|Black Truck|cargo|delivery|delivery truck|shipping|truck|vehicle"},
{0xe58b, false, "truck arrow right|access|fast|shipping|transport"},
{0xe58c, false, "truck droplet|blood|thirst|truck|water|water supply"},
{0xf48b, false, "truck fast|express|fedex|mail|overnight|package|quick|ups"},
{0xe58d, false, "truck field|supplies|truck"},
{0xe58e, false, "truck field un|supplies|truck|united nations"},
{0xe2b7, false, "truck front|shuttle|truck|van"},
{0xf0f9, false, "truck medical|ambulance|clinic|covid-19|emergency|emt|er|help|hospital|mobile|support|vehicle"},
{0xf63b, false, "truck monster|offroad|vehicle|wheel"},
{0xf4df, false, "truck moving|cargo|inventory|rental|vehicle"},
{0xf63c, false, "truck pickup|cargo|maintenance|pick-up|pickup|pickup truck|truck|vehicle"},
{0xe58f, false, "truck plane|airplane|plane|transportation|truck|vehicle"},
{0xf4de, false, "truck ramp box|box|cargo|delivery|inventory|moving|rental|vehicle"},
{0xf1e4, false, "tty|communication|deaf|telephone|teletypewriter|text"},
{0xe2bb, false, "turkish lira sign|Turkish Lira Sign|currency"},
{0xf3be, false, "turn down|arrow|down|level-down|right arrow curving down"},
{0xf3bf, false, "turn up|arrow|level-up|right arrow curving up"},
{0xf26c, false, "tv|computer|display|monitor|television"},
{0x55, false, "u|Latin Capital Letter U|Latin Small Letter U|letter"},
{0xf0e9, false, "umbrella|protection|rain|storm|wet"},
{0xf5ca, false, "umbrella beach|beach|beach with umbrella|protection|recreation|sand|shade|summer|sun|umbrella"},
{0xf0cd, false, "underline|edit|emphasis|format|modify|text|writing"},
{0xf29a, false, "universal access|uer|users-people"},
{0xf09c, false, "unlock|admin|lock|open|padlock|password|privacy|private|protect|unlock|unlocked"},
{0xf13e, false, "unlock keyhole|admin|lock|padlock|password|privacy|private|protect"},
{0xf338, false, "up down|Up Down Black Arrow|arrow|arrows-v|expand|portrait|resize|tall|up-down arrow|vertical"},
{0xf0b2, false, "up down left right|arrow|arrows|bigger|enlarge|expand|fullscreen|move|position|reorder|resize"},
{0xf30c, false, "up long|long-arrow-up|upgrade|upload"},
{0xf424, false, "up right and down left from center| maximize| resize| scale|arrows|bigger|enlarge|expand|fullscreen|resize|size"},
{0xf35d, false, "up right from square|external-link|new|open|share|upgrade"},
{0xf093, false, "upload|hard drive|import|publish|upgrade"},
{0xf007, false, "user|adult|bust|bust in silhouette|default|employee|gender-neutral|person|profile|silhouette|uer|unspecified gender|username|users-people"},
{0xf4fb, false, "user astronaut|avatar|clothing|cosmonaut|nasa|space|suit|uer"},
{0xf4fc, false, "user check|employee|enable|uer|users-people|validate|working"},
{0xf4fd, false, "user clock|employee|uer|users-people"},
{0xf0f0, false, "user doctor|covid-19|health|job|medical|nurse|occupation|physician|profile|surgeon|uer|worker"},
{0xf4fe, false, "user gear|employee|together|uer|users-people"},
{0xf501, false, "user graduate|uer|users-people"},
{0xf500, false, "user group|bust|busts in silhouette|crowd|employee|silhouette|together|uer|users-people"},
{0xf728, false, "user injured|employee|uer|users-people"},
{0xf406, false, "user large|employee|uer|users-people"},
{0xf4fa, false, "user large slash|disabled|disconnect|employee|uer|users-people"},
{0xf502, false, "user lock|employee|padlock|privacy|uer|users-people"},
{0xf503, false, "user minus|delete|employee|negative|remove|uer"},
{0xf504, false, "user ninja|assassin|avatar|dangerous|deadly|fighter|hidden|ninja|sneaky|stealth|uer"},
{0xf82f, false, "user nurse|covid-19|doctor|health|md|medical|midwife|physician|practitioner|surgeon|uer|worker"},
{0xf4ff, false, "user pen|employee|modify|uer|users-people"},
{0xf234, false, "user plus|add|avatar|employee|follow|positive|sign up|signup|team|uer"},
{0xf21b, false, "user secret|detective|sleuth|spy|uer|users-people"},
{0xf505, false, "user shield|employee|protect|safety|uer"},
{0xf506, false, "user slash|ban|delete|deny|disabled|disconnect|employee|remove|uer"},
{0xf507, false, "user tag|employee|uer|users-people"},
{0xf508, false, "user tie|administrator|avatar|business|clothing|employee|formal|offer|portfolio|professional|suit|uer"},
{0xf235, false, "user xmark|archive|delete|employee|remove|uer|uncheck|x"},
{0xf0c0, false, "users|employee|together|uer|users-people"},
{0xe591, false, "users between lines|covered|crowd|employee|group|people|together|uer"},
{0xf509, false, "users gear|employee|uer|users-people"},
{0xe592, false, "users line|crowd|employee|group|need|people|together|uer"},
{0xe593, false, "users rays|affected|crowd|employee|focused|group|people|uer"},
{0xe594, false, "users rectangle|crowd|employee|focus|group|people|reached|uer"},
{0xe073, false, "users slash|disabled|disconnect|employee|together|uer|users-people"},
{0xe595, false, "users viewfinder|crowd|focus|group|people|targeted|uer"},
{0xf2e7, false, "utensils|cooking|cutlery|dining|dinner|eat|food|fork|fork and knife|knife|restaurant"},
{0x56, false, "v|Latin Capital Letter V|Latin Small Letter V|letter"},
{0xf5b6, false, "van shuttle|airport|bus|machine|minibus|public-transportation|transportation|travel|vehicle"},
{0xe2c5, false, "vault|bank|important|investment|lock|money|premium|privacy|safe|salary"},
{0xf5cb, false, "vector square|anchors|lines|object|render|shape"},
{0xf221, false, "venus|female|female sign|gender|woman"},
{0xf226, false, "venus double|Doubled Female Sign|female|gender|lesbian"},
{0xf228, false, "venus mars|Interlocked Female and Male Sign|female|gender|heterosexual|male"},
{0xe085, false, "vest|biker|fashion|style"},
{0xe086, false, "vest patches|biker|fashion|style"},
{0xf492, false, "vial|ampule|chemist|chemistry|experiment|knowledge|lab|sample|science|test|test tube"},
{0xe596, false, "vial circle check|ampule|chemist|chemistry|enable|not affected|ok|okay|success|test tube|tube|vaccine|validate|working"},
{0xe597, false, "vial virus|ampule|coronavirus|covid-19|flue|infection|lab|laboratory|pandemic|test|test tube|vaccine"},
{0xf493, false, "vials|ampule|experiment|knowledge|lab|sample|science|test|test tube"},
{0xf03d, false, "video|camera|film|movie|record|video-camera"},
{0xf4e2, false, "video slash|add|create|disabled|disconnect|film|new|positive|record|video"},
{0xf6a7, false, "vihara|buddhism|buddhist|building|monastery"},
{0xe074, false, "virus|bug|coronavirus|covid-19|flu|health|infection|pandemic|sick|vaccine|viral"},
{0xe4a8, false, "virus covid|bug|covid-19|flu|health|infection|pandemic|vaccine|viral|virus"},
{0xe4a9, false, "virus covid slash|bug|covid-19|disabled|flu|health|infection|pandemic|vaccine|viral|virus"},
{0xe075, false, "virus slash|bug|coronavirus|covid-19|cure|disabled|eliminate|flu|health|infection|pandemic|sick|vaccine|viral"},
{0xe076, false, "viruses|bugs|coronavirus|covid-19|flu|health|infection|multiply|pandemic|sick|spread|vaccine|viral"},
{0xf897, false, "voicemail|answer|inbox|message|phone"},
{0xf770, false, "volcano|caldera|eruption|lava|magma|mountain|smoke|volcano"},
{0xf45f, false, "volleyball|ball|beach|game|olympics|sport|volleyball"},
{0xf028, false, "volume high|audio|higher|loud|louder|music|sound|speaker|speaker high volume"},
{0xf027, false, "volume low|audio|lower|music|quieter|soft|sound|speaker|speaker low volume"},
{0xf026, false, "volume off|audio|ban|music|mute|quiet|silent|sound"},
{0xf6a9, false, "volume xmark|audio|music|quiet|sound|speaker"},
{0xf729, false, "vr cardboard|3d|augment|google|reality|virtual"},
{0x57, false, "w|Latin Capital Letter W|Latin Small Letter W|letter"},
{0xf8ef, false, "walkie talkie|communication|copy|intercom|over|portable|radio|two way radio"},
{0xf555, false, "wallet|billfold|cash|currency|money|salary"},
{0xf0d0, false, "wand magic|autocomplete|automatic|mage|magic|spell|wand|witch|wizard"},
{0xe2ca, false, "wand magic sparkles|auto|magic|magic wand|trick|witch|wizard"},
{0xf72b, false, "wand sparkles|autocomplete|automatic|fantasy|halloween|holiday|magic|weapon|witch|wizard"},
{0xf494, false, "warehouse|building|capacity|garage|inventory|storage"},
{0xf773, false, "water|lake|liquid|ocean|sea|swim|wet"},
{0xf5c5, false, "water ladder|ladder|recreation|swim|water"},
{0xf83e, false, "wave square|frequency|pulse|signal"},
{0xf5cd, false, "weight hanging|anvil|heavy|measurement"},
{0xf496, false, "weight scale|health|measurement|scale|weight"},
{0xe2cd, false, "wheat awn|agriculture|autumn|fall|farming|grain"},
{0xe598, false, "wheat awn circle exclamation|affected|failed|famine|food|gluten|hunger|starve|straw"},
{0xf193, false, "wheelchair|disabled|uer|users-people"},
{0xe2ce, false, "wheelchair move|access|disabled|handicap|impairment|physical|uer|wheelchair symbol"},
{0xf7a0, false, "whiskey glass|alcohol|bar|beverage|bourbon|drink|glass|liquor|neat|rye|scotch|shot|tumbler|tumbler glass|whisky"},
{0xf1eb, false, "wifi|connection|hotspot|internet|network|wireless|www"},
{0xf72e, false, "wind|air|blow|breeze|fall|seasonal|weather"},
{0xf2d0, false, "window maximize|Maximize|browser|computer|development|expand"},
{0xf2d1, false, "window minimize|Minimize|browser|collapse|computer|development"},
{0xf2d2, false, "window restore|browser|computer|development"},
{0xf72f, false, "wine bottle|alcohol|beverage|cabernet|drink|glass|grapes|merlot|sauvignon"},
{0xf4e3, false, "wine glass|alcohol|bar|beverage|cabernet|drink|glass|grapes|merlot|sauvignon|wine|wine glass"},
{0xf5ce, false, "wine glass empty|alcohol|beverage|cabernet|drink|grapes|merlot|sauvignon"},
{0xf159, false, "won sign|Won Sign|currency"},
{0xe599, false, "worm|dirt|garden|worm|wriggle"},
{0xf0ad, false, "wrench|configuration|construction|equipment|fix|mechanic|modify|plumbing|settings|spanner|tool|update|wrench"},
{0x58, false, "x|Latin Capital Letter X|Latin Small Letter X|letter|uncheck"},
{0xf497, false, "x ray|health|medical|radiological images|radiology|skeleton"},
{0xf00d, false, "xmark|Cancellation X|Multiplication Sign|Multiplication X|cancel|close|cross|cross mark|error|exit|incorrect|mark|multiplication|multiply|notice|notification|notify|problem|sign|uncheck|wrong|x|×"},
{0xe59a, false, "xmarks lines|barricade|barrier|fence|poison|roadblock"},
{0x59, false, "y|Latin Capital Letter Y|Latin Small Letter Y|letter|yay|yes"},
{0xf157, false, "yen sign|Yen Sign|currency"},
{0xf6ad, false, "yin yang|daoism|opposites|religion|tao|taoism|taoist|yang|yin|yin yang"},
{0x5a, false, "z|Latin Capital Letter Z|Latin Small Letter Z|letter"},
{0xe080, true, "42.group"},
{0xf26e, true, "500px"},
{0xf368, true, "accessible icon|accessibility|disabled|handicap|person|uer|wheelchair|wheelchair-alt"},
{0xf369, true, "accusoft"},
{0xf170, true, "app.net"},
{0xf36a, true, "adversal"},
{0xf36b, true, "affiliatetheme"},
{0xf834, true, "airbnb"},
{0xf36c, true, "algolia"},
{0xf642, true, "alipay"},
{0xf270, true, "amazon"},
{0xf42c, true, "amazon pay"},
{0xf36d, true, "amilia"},
{0xf17b, true, "android|robot"},
{0xf209, true, "angellist"},
{0xf36e, true, "angry creative"},
{0xf420, true, "angular"},
{0xf36f, true, "app store"},
{0xf370, true, "ios app store"},
{0xf371, true, "apper systems ab"},
{0xf179, true, "apple|fruit|ios|mac|operating system|os|osx"},
{0xf415, true, "apple pay"},
{0xf77a, true, "artstation"},
{0xf372, true, "asymmetrik, ltd."},
{0xf77b, true, "atlassian"},
{0xf373, true, "audible"},
{0xf41c, true, "autoprefixer"},
{0xf374, true, "avianex"},
{0xf421, true, "aviato"},
{0xf375, true, "amazon web services (aws)"},
{0xf2d5, true, "bandcamp"},
{0xf835, true, "battle.net"},
{0xf1b4, true, "behance"},
{0xe3d9, true, "bilibili"},
{0xf378, true, "bimobject"},
{0xf171, true, "bitbucket|atlassian|bitbucket-square|git"},
{0xf379, true, "bitcoin"},
{0xf37a, true, "bity"},
{0xf27e, true, "font awesome black tie|administrator"},
{0xf37b, true, "blackberry"},
{0xf37c, true, "blogger"},
{0xf37d, true, "blogger b"},
{0xf293, true, "bluetooth|signal"},
{0xf294, true, "bluetooth"},
{0xf836, true, "bootstrap"},
{0xe340, true, "bots"},
{0xe63c, true, "brave"},
{0xe63d, true, "brave reverse"},
{0xf15a, true, "btc"},
{0xf837, true, "buffer"},
{0xf37f, true, "büromöbel-experte gmbh & co. kg."},
{0xf8a6, true, "buy n large"},
{0xf20d, true, "buysellads"},
{0xf785, true, "canadian maple leaf|canada|flag|flora|nature|plant"},
{0xf42d, true, "amazon pay credit card"},
{0xf1f3, true, "cc amex|amex"},
{0xf416, true, "apple pay credit card"},
{0xf24c, true, "diner's club credit card"},
{0xf1f2, true, "discover credit card"},
{0xf24b, true, "jcb credit card"},
{0xf1f1, true, "mastercard credit card"},
{0xf1f4, true, "paypal credit card"},
{0xf1f5, true, "stripe credit card"},
{0xf1f0, true, "visa credit card"},
{0xf380, true, "centercode"},
{0xf789, true, "centos|linux|operating system|os"},
{0xf268, true, "chrome|browser"},
{0xf838, true, "chromecast"},
{0xe07d, true, "cloudflare"},
{0xf383, true, "cloudscale.ch"},
{0xf384, true, "cloudsmith"},
{0xf385, true, "cloudversify"},
{0xe360, true, "cmplid"},
{0xf1cb, true, "codepen"},
{0xf284, true, "codie pie"},
{0xf78d, true, "confluence|atlassian"},
{0xf20e, true, "connect develop"},
{0xf26d, true, "contao"},
{0xf89e, true, "cotton bureau|clothing|t-shirts|tshirts"},
{0xf388, true, "cpanel"},
{0xf25e, true, "creative commons"},
{0xf4e7, true, "creative commons attribution"},
{0xf4e8, true, "creative commons noncommercial"},
{0xf4e9, true, "creative commons noncommercial (euro sign)"},
{0xf4ea, true, "creative commons noncommercial (yen sign)"},
{0xf4eb, true, "creative commons no derivative works"},
{0xf4ec, true, "creative commons public domain"},
{0xf4ed, true, "alternate creative commons public domain"},
{0xf4ee, true, "creative commons remix"},
{0xf4ef, true, "creative commons share alike"},
{0xf4f0, true, "creative commons sampling"},
{0xf4f1, true, "creative commons sampling +"},
{0xf4f2, true, "creative commons share"},
{0xf4f3, true, "creative commons cc0"},
{0xf6c9, true, "critical role|Dungeons & Dragons|d&d|dnd|fantasy|game|gaming|tabletop"},
{0xf13c, true, "css 3 logo|code"},
{0xf38b, true, "alternate css3 logo"},
{0xf38c, true, "cuttlefish"},
{0xf38d, true, "dungeons & dragons"},
{0xf6ca, true, "d&d beyond|Dungeons & Dragons|d&d|dnd|fantasy|gaming|tabletop"},
{0xe052, true, "dailymotion"},
{0xf210, true, "dashcube"},
{0xe60b, true, "debian"},
{0xe077, true, "deezer"},
{0xf1a5, true, "delicious"},
{0xf38e, true, "deploy.dog"},
{0xf38f, true, "deskpro"},
{0xf6cc, true, "dev"},
{0xf1bd, true, "deviantart"},
{0xf790, true, "dhl|Dalsey|Hillblom and Lynn|german|package|shipping"},
{0xf791, true, "diaspora"},
{0xf1a6, true, "digg logo"},
{0xf391, true, "digital ocean"},
{0xf392, true, "discord"},
{0xf393, true, "discourse"},
{0xf394, true, "dochub"},
{0xf395, true, "docker"},
{0xf396, true, "draft2digital"},
{0xf17d, true, "dribbble"},
{0xf16b, true, "dropbox"},
{0xf1a9, true, "drupal logo"},
{0xf399, true, "dyalog"},
{0xf39a, true, "earlybirds"},
{0xf4f4, true, "ebay"},
{0xf282, true, "edge browser|browser|ie"},
{0xe078, true, "edge legacy browser"},
{0xf430, true, "elementor"},
{0xf5f1, true, "ello"},
{0xf423, true, "ember"},
{0xf1d1, true, "galactic empire"},
{0xf299, true, "envira gallery|leaf"},
{0xf39d, true, "erlang"},
{0xf42e, true, "ethereum"},
{0xf2d7, true, "etsy"},
{0xf839, true, "evernote"},
{0xf23e, true, "expeditedssl"},
{0xf09a, true, "facebook|fabook|facebook-official|fb|social network"},
{0xf39e, true, "facebook f|fabook|facebook|fb"},
{0xf39f, true, "facebook messenger|fabook|fb"},
{0xf6dc, true, "fantasy flight-games|Dungeons & Dragons|d&d|dnd|fantasy|game|gaming|tabletop"},
{0xf797, true, "fedex|Federal Express|package|shipping"},
{0xf798, true, "fedora|linux|operating system|os"},
{0xf799, true, "figma|app|design|interface"},
{0xf269, true, "firefox|browser"},
{0xe007, true, "firefox browser|browser"},
{0xf2b0, true, "first order"},
{0xf50a, true, "alternate first order"},
{0xf3a1, true, "firstdraft"},
{0xf16e, true, "flickr"},
{0xf44d, true, "flipboard"},
{0xf417, true, "fly"},
{0xf2b4, true, "font awesome|awesome|flag|font|icons|typeface"},
{0xf280, true, "fonticons"},
{0xf3a2, true, "fonticons fi"},
{0xf286, true, "fort awesome|castle"},
{0xf3a3, true, "alternate fort awesome|castle"},
{0xf211, true, "forumbee"},
{0xf180, true, "foursquare"},
{0xf2c5, true, "freecodecamp"},
{0xf3a4, true, "freebsd"},
{0xf50b, true, "fulcrum"},
{0xf50c, true, "galactic republic|politics|star wars"},
{0xf50d, true, "galactic senate|star wars"},
{0xf265, true, "get pocket"},
{0xf260, true, "gg currency"},
{0xf261, true, "gg currency circle"},
{0xf1d3, true, "git"},
{0xf841, true, "git alt"},
{0xf09b, true, "github|octocat"},
{0xf113, true, "alternate github|octocat"},
{0xf3a6, true, "gitkraken"},
{0xf296, true, "gitlab|Axosoft"},
{0xf426, true, "gitter"},
{0xf2a5, true, "glide"},
{0xf2a6, true, "glide g"},
{0xf3a7, true, "gofore"},
{0xe40f, true, "go"},
{0xf3a8, true, "goodreads"},
{0xf3a9, true, "goodreads g"},
{0xf1a0, true, "google logo"},
{0xf3aa, true, "google drive"},
{0xe079, true, "google pay"},
{0xf3ab, true, "google play|playstore"},
{0xf2b3, true, "google plus|google-plus-circle|google-plus-official"},
{0xf0d5, true, "google plus g|google-plus|social network"},
{0xe63b, true, "google scholar"},
{0xf1ee, true, "google wallet"},
{0xf184, true, "gratipay (gittip)|favorite|heart|like|love"},
{0xf2d6, true, "grav"},
{0xf3ac, true, "gripfire, inc."},
{0xf3ad, true, "grunt"},
{0xe07e, true, "guilded"},
{0xf3ae, true, "gulp"},
{0xf1d4, true, "hacker news"},
{0xf5f7, true, "hackerrank"},
{0xe499, true, "hashnode"},
{0xf452, true, "hips"},
{0xf3b0, true, "hireahelper"},
{0xe07f, true, "hive blockchain network"},
{0xf427, true, "hooli"},
{0xf592, true, "hornbill"},
{0xf3b1, true, "hotjar"},
{0xf27c, true, "houzz"},
{0xf13b, true, "html 5 logo"},
{0xf3b2, true, "hubspot"},
{0xe013, true, "ideal"},
{0xf2d8, true, "imdb"},
{0xf16d, true, "instagram"},
{0xe081, true, "instalod"},
{0xf7af, true, "intercom|app|customer|messenger"},
{0xf26b, true, "internet-explorer|browser|ie"},
{0xf7b0, true, "invision|app|design|interface"},
{0xf208, true, "ioxhost"},
{0xf83a, true, "itch.io"},
{0xf3b4, true, "itunes"},
{0xf3b5, true, "itunes note"},
{0xf4e4, true, "java"},
{0xf50e, true, "jedi order|star wars"},
{0xf3b6, true, "jenkis"},
{0xf7b1, true, "jira|atlassian"},
{0xf3b7, true, "joget"},
{0xf1aa, true, "joomla logo"},
{0xf3b8, true, "javascript (js)"},
{0xf1cc, true, "jsfiddle"},
{0xf5fa, true, "kaggle"},
{0xf4f5, true, "keybase"},
{0xf3ba, true, "keycdn"},
{0xf3bb, true, "kickstarter"},
{0xf3bc, true, "kickstarter k"},
{0xf42f, true, "korvue"},
{0xf3bd, true, "laravel"},
{0xf202, true, "last.fm"},
{0xf212, true, "leanpub"},
{0xf41d, true, "less"},
{0xe62d, true, "letterboxd"},
{0xf3c0, true, "line"},
{0xf08c, true, "linkedin|linkedin-square|linkin"},
{0xf0e1, true, "linkedin in|linkedin|linkin"},
{0xf2b8, true, "linode"},
{0xf17c, true, "linux|tux"},
{0xf3c3, true, "lyft"},
{0xf3c4, true, "magento"},
{0xf59e, true, "mailchimp"},
{0xf50f, true, "mandalorian"},
{0xf60f, true, "markdown"},
{0xf4f6, true, "mastodon"},
{0xf136, true, "maxcdn"},
{0xf8ca, true, "material design for bootstrap"},
{0xf3c6, true, "medapps"},
{0xf23a, true, "medium"},
{0xf3c8, true, "mrt"},
{0xf2e0, true, "meetup"},
{0xf5a3, true, "megaport"},
{0xf7b3, true, "mendeley"},
{0xe49b, true, "meta"},
{0xe01a, true, "micro.blog"},
{0xf3ca, true, "microsoft"},
{0xe62f, true, "mintbit"},
{0xf3cb, true, "mix"},
{0xf289, true, "mixcloud"},
{0xe056, true, "mixer"},
{0xf3cc, true, "mizuni"},
{0xf285, true, "modx"},
{0xf3d0, true, "monero"},
{0xf3d2, true, "napster"},
{0xf612, true, "neos"},
{0xe530, true, "nfc directional|connect|data|near field communication|nfc|scan|signal|transfer|wireless"},
{0xe531, true, "nfc symbol|connect|data|near field communication|nfc|scan|signal|transfer|wireless"},
{0xf5a8, true, "nimblr"},
{0xf419, true, "node.js"},
{0xf3d3, true, "node.js js"},
{0xf3d4, true, "npm"},
{0xf3d5, true, "ns8"},
{0xf3d6, true, "nutritionix"},
{0xe082, true, "octopus deploy"},
{0xf263, true, "odnoklassniki"},
{0xe5c6, true, "odysee"},
{0xf510, true, "old republic|politics|star wars"},
{0xf23d, true, "opencart"},
{0xf19b, true, "openid"},
{0xe62b, true, "opensuse"},
{0xf26a, true, "opera"},
{0xf23c, true, "optin monster"},
{0xf8d2, true, "orcid"},
{0xf41a, true, "open source initiative"},
{0xe4a0, true, "padlet"},
{0xf3d7, true, "page4 corporation"},
{0xf18c, true, "pagelines|eco|flora|leaf|leaves|nature|plant|tree"},
{0xf3d8, true, "palfed"},
{0xf3d9, true, "patreon"},
{0xf1ed, true, "paypal"},
{0xe083, true, "perbyte"},
{0xf3da, true, "periscope"},
{0xf3db, true, "phabricator"},
{0xf3dc, true, "phoenix framework"},
{0xf511, true, "phoenix squadron"},
{0xf457, true, "php"},
{0xf2ae, true, "pied piper logo"},
{0xf1a8, true, "alternate pied piper logo (old)"},
{0xf4e5, true, "pied piper hat (old)|clothing"},
{0xf1a7, true, "pied piper pp logo (old)"},
{0xf0d2, true, "pinterest"},
{0xf231, true, "pinterest p"},
{0xe43a, true, "pix"},
{0xe640, true, "pixiv"},
{0xf3df, true, "playstation"},
{0xf288, true, "product hunt"},
{0xf3e1, true, "pushed"},
{0xf3e2, true, "python"},
{0xf1d6, true, "qq"},
{0xf459, true, "quinscape"},
{0xf2c4, true, "quora"},
{0xf4f7, true, "r project"},
{0xf7bb, true, "raspberry pi"},
{0xf2d9, true, "ravelry"},
{0xf41b, true, "react"},
{0xf75d, true, "reacteurope"},
{0xf4d5, true, "readme"},
{0xf1d0, true, "rebel alliance"},
{0xf3e3, true, "red river"},
{0xf1a1, true, "reddit"},
{0xf281, true, "reddit alien"},
{0xf7bc, true, "redhat|linux|operating system|os"},
{0xf18b, true, "renren"},
{0xf3e6, true, "replyd"},
{0xf4f8, true, "researchgate"},
{0xf3e7, true, "resolving"},
{0xf5b2, true, "rev.io"},
{0xf3e8, true, "rocket.chat"},
{0xf3e9, true, "rockrms"},
{0xe07a, true, "rust"},
{0xf267, true, "safari|browser"},
{0xf83b, true, "salesforce"},
{0xf41e, true, "sass"},
{0xf3ea, true, "schlix"},
{0xe570, true, "screenpal"},
{0xf28a, true, "scribd"},
{0xf3eb, true, "searchengin"},
{0xf2da, true, "sellcast|eercast"},
{0xf213, true, "sellsy"},
{0xf3ec, true, "servicestack"},
{0xf214, true, "shirts in bulk"},
{0xe60c, true, "shoelace"},
{0xe057, true, "shopify"},
{0xf5b5, true, "shopware"},
{0xe663, true, "signal messenger"},
{0xf215, true, "simplybuilt"},
{0xf3ee, true, "sistrix"},
{0xf512, true, "sith"},
{0xe44a, true, "sitrox"},
{0xf7c6, true, "sketch|app|design|interface"},
{0xf216, true, "skyatlas"},
{0xf17e, true, "skype"},
{0xf198, true, "slack logo|anchor|hash|hashtag"},
{0xf1e7, true, "slideshare"},
{0xf2ab, true, "snapchat"},
{0xf1be, true, "soundcloud"},
{0xf7d3, true, "sourcetree"},
{0xe5ac, true, "space awesome|adventure|rocket|ship|shuttle"},
{0xf3f3, true, "speakap"},
{0xf83c, true, "speaker deck"},
{0xf1bc, true, "spotify"},
{0xf1b5, true, "square behance"},
{0xf397, true, "square dribbble"},
{0xf082, true, "square facebook|fabook|fb|social network"},
{0xe5ad, true, "font awesome in square"},
{0xf35c, true, "font awesome in square with stroke outline"},
{0xf1d2, true, "square git"},
{0xf092, true, "square github|octocat"},
{0xe5ae, true, "square gitlab"},
{0xf0d4, true, "square google plus|social network"},
{0xf3af, true, "square hacker news"},
{0xe055, true, "square instagram"},
{0xf3b9, true, "square js"},
{0xf203, true, "square lastfm"},
{0xe62e, true, "square letterboxd"},
{0xf264, true, "square odnoklassniki"},
{0xe01e, true, "pied piper square logo (old)"},
{0xf0d3, true, "square pinterest"},
{0xf1a2, true, "square reddit"},
{0xf2ad, true, "snapchat square"},
{0xf1b7, true, "square steam"},
{0xe619, true, "square threads"},
{0xf174, true, "square tumblr"},
{0xf081, true, "square twitter|social network|tweet"},
{0xf2aa, true, "square viadeo"},
{0xf194, true, "square vimeo"},
{0xf40c, true, "square whatsapp"},
{0xe61a, true, "square x twitter| elon| x|twitter"},
{0xf169, true, "square xing"},
{0xf431, true, "square youtube"},
{0xf5be, true, "squarespace"},
{0xf18d, true, "stack exchange"},
{0xf16c, true, "stack overflow"},
{0xf842, true, "stackpath"},
{0xf3f5, true, "staylinked|linkin"},
{0xf1b6, true, "steam"},
{0xf3f6, true, "steam symbol"},
{0xf3f7, true, "sticker mule"},
{0xf428, true, "strava"},
{0xf429, true, "stripe"},
{0xf42a, true, "stripe s"},
{0xe5c7, true, "stubber"},
{0xf3f8, true, "studio vinari"},
{0xf1a4, true, "stumbleupon logo"},
{0xf1a3, true, "stumbleupon circle"},
{0xf2dd, true, "superpowers"},
{0xf3f9, true, "supple"},
{0xf7d6, true, "suse|linux|operating system|os"},
{0xf8e1, true, "swift"},
{0xf83d, true, "symfony"},
{0xf4f9, true, "teamspeak"},
{0xf2c6, true, "telegram"},
{0xf1d5, true, "tencent weibo"},
{0xf69d, true, "the red yeti"},
{0xf5c6, true, "themeco"},
{0xf2b2, true, "themeisle"},
{0xf731, true, "think peaks"},
{0xe618, true, "threads"},
{0xe07b, true, "tiktok"},
{0xf513, true, "trade federation"},
{0xf181, true, "trello|atlassian"},
{0xf173, true, "tumblr"},
{0xf1e8, true, "twitch"},
{0xf099, true, "twitter|social network|tweet"},
{0xf42b, true, "typo3"},
{0xf402, true, "uber"},
{0xf7df, true, "ubuntu|linux|operating system|os"},
{0xf403, true, "uikit"},
{0xf8e8, true, "umbraco"},
{0xe084, true, "uncharted software"},
{0xf404, true, "uniregistry"},
{0xe049, true, "unity 3d"},
{0xe07c, true, "unsplash"},
{0xf405, true, "untappd"},
{0xf7e0, true, "ups|United Parcel Service|package|shipping"},
{0xe641, true, "upwork"},
{0xf287, true, "usb"},
{0xf7e1, true, "united states postal service|american|package|shipping|usa"},
{0xf407, true, "us-sunnah foundation"},
{0xf408, true, "vaadin"},
{0xf237, true, "viacoin"},
{0xf2a9, true, "viadeo"},
{0xf409, true, "viber"},
{0xf40a, true, "vimeo"},
{0xf27d, true, "vimeo|vimeo"},
{0xf1ca, true, "vine"},
{0xf189, true, "vk"},
{0xf40b, true, "vnv"},
{0xf41f, true, "vue.js"},
{0xe087, true, "watchman monitoring"},
{0xf83f, true, "waze"},
{0xe65c, true, "webflow"},
{0xf5cc, true, "weebly"},
{0xf18a, true, "weibo"},
{0xf1d7, true, "weixin (wechat)"},
{0xf232, true, "what's app"},
{0xf40d, true, "whmcs"},
{0xf266, true, "wikipedia w"},
{0xf17a, true, "windows|microsoft|operating system|os"},
{0xe2d0, true, "wirsindhandwerk"},
{0xf5cf, true, "wix"},
{0xf730, true, "wizards of the coast|Dungeons & Dragons|d&d|dnd|fantasy|game|gaming|tabletop"},
{0xe088, true, "wodu"},
{0xf514, true, "wolf pack battalion"},
{0xf19a, true, "wordpress logo"},
{0xf411, true, "wordpress simple"},
{0xf297, true, "wpbeginner"},
{0xf2de, true, "wpexplorer"},
{0xf298, true, "wpforms"},
{0xf3e4, true, "wpressr|rendact"},
{0xe61b, true, "x twitter|  elon| twitter| x"},
{0xf412, true, "xbox"},
{0xf168, true, "xing"},
{0xf23b, true, "y combinator"},
{0xf19e, true, "yahoo logo"},
{0xf840, true, "yammer"},
{0xf413, true, "yandex"},
{0xf414, true, "yandex international"},
{0xf7e3, true, "yarn"},
{0xf1e9, true, "yelp"},
{0xf2b1, true, "yoast"},
{0xf167, true, "youtube|film|video|youtube-play|youtube-square"},
{0xf63f, true, "zhihu"}
};
